@@ -1495,6 +1495,33 @@ virDomainDefIOMMUValidate(const virDomainDef *def)
 }
 
 
+static int
+virDomainDefFSValidate(const virDomainDef *def)
+{
+    size_t i;
+    g_autoptr(GHashTable) dsts = virHashNew(NULL);
+
+    for (i = 0; i < def->nfss; i++) {
+        const virDomainFSDef *fs = def->fss[i];
+
+        if (fs->fsdriver != VIR_DOMAIN_FS_DRIVER_TYPE_VIRTIOFS)
+            continue;
+
+        if (virHashHasEntry(dsts, fs->dst)) {
+            virReportError(VIR_ERR_CONFIG_UNSUPPORTED,
+                           _("filesystem target '%s' specified twice"),
+                           fs->dst);
+            return -1;
+        }
+
+        if (virHashAddEntry(dsts, fs->dst, (void *) 0x1) < 0)
+            return -1;
+    }
+
+    return 0;
+}
+
+
 static int
 virDomainDefValidateInternal(const virDomainDef *def,
                              virDomainXMLOption *xmlopt)
@@ -1541,6 +1568,9 @@ virDomainDefValidateInternal(const virDomainDef *def,
     if (virDomainNumaDefValidate(def->numa) < 0)
         return -1;
 
+    if (virDomainDefFSValidate(def) < 0)
+        return -1;
+
     return 0;
 }
 
@@ -2006,6 +2036,16 @@ virDomainShmemDefValidate(const virDomainShmemDef *shmem)
 static int
 virDomainFSDefValidate(const virDomainFSDef *fs)
 {
+    if (fs->dst == NULL) {
+        const char *source = fs->src->path;
+        if (!source)
+            source = fs->sock;
+
+        virReportError(VIR_ERR_NO_TARGET,
+                       source ? "%s" : NULL, source);
+        return -1;
+    }
+
     if (fs->info.bootIndex &&
         fs->fsdriver != VIR_DOMAIN_FS_DRIVER_TYPE_VIRTIOFS) {
         virReportError(VIR_ERR_CONFIG_UNSUPPORTED, "%s",
