@@ -49,9 +49,8 @@ struct _virChrdevs {
 };
 
 typedef struct _virChrdevStreamInfo virChrdevStreamInfo;
-typedef virChrdevStreamInfo *virChrdevStreamInfoPtr;
 struct _virChrdevStreamInfo {
-    virChrdevsPtr devs;
+    virChrdevs *devs;
     char *path;
 };
 
@@ -221,7 +220,7 @@ static void virChrdevHashEntryFree(void *data)
  */
 static void virChrdevFDStreamCloseCbFree(void *opaque)
 {
-    virChrdevStreamInfoPtr priv = opaque;
+    virChrdevStreamInfo *priv = opaque;
 
     g_free(priv->path);
     g_free(priv);
@@ -237,7 +236,7 @@ static void virChrdevFDStreamCloseCbFree(void *opaque)
 static void virChrdevFDStreamCloseCb(virStreamPtr st G_GNUC_UNUSED,
                                       void *opaque)
 {
-    virChrdevStreamInfoPtr priv = opaque;
+    virChrdevStreamInfo *priv = opaque;
     virMutexLock(&priv->devs->lock);
 
     /* remove entry from hash */
@@ -252,9 +251,9 @@ static void virChrdevFDStreamCloseCb(virStreamPtr st G_GNUC_UNUSED,
  *
  * Returns pointer to the allocated structure or NULL on error
  */
-virChrdevsPtr virChrdevAlloc(void)
+virChrdevs *virChrdevAlloc(void)
 {
-    virChrdevsPtr devs;
+    virChrdevs *devs;
     devs = g_new0(virChrdevs, 1);
 
     if (virMutexInit(&devs->lock) < 0) {
@@ -293,7 +292,7 @@ static int virChrdevFreeClearCallbacks(void *payload,
  *
  * @devs Pointer to the private structure.
  */
-void virChrdevFree(virChrdevsPtr devs)
+void virChrdevFree(virChrdevs *devs)
 {
     if (!devs)
         return;
@@ -323,12 +322,12 @@ void virChrdevFree(virChrdevsPtr devs)
  * corresponding lock file is created (if configured). Returns -1 on
  * error and 1 if the device stream is open and busy.
  */
-int virChrdevOpen(virChrdevsPtr devs,
-                  virDomainChrSourceDefPtr source,
+int virChrdevOpen(virChrdevs *devs,
+                  virDomainChrSourceDef *source,
                   virStreamPtr st,
                   bool force)
 {
-    virChrdevStreamInfoPtr cbdata = NULL;
+    virChrdevStreamInfo *cbdata = NULL;
     virChrdevHashEntry *ent;
     char *path;
     int ret;
