@@ -38,10 +38,10 @@
 
 VIR_LOG_INIT("conf.virstorageobj");
 
-static virClassPtr virStoragePoolObjClass;
-static virClassPtr virStoragePoolObjListClass;
-static virClassPtr virStorageVolObjClass;
-static virClassPtr virStorageVolObjListClass;
+static virClass *virStoragePoolObjClass;
+static virClass *virStoragePoolObjListClass;
+static virClass *virStorageVolObjClass;
+static virClass *virStorageVolObjListClass;
 
 static void
 virStoragePoolObjDispose(void *opaque);
@@ -55,15 +55,13 @@ virStorageVolObjListDispose(void *opaque);
 
 
 typedef struct _virStorageVolObj virStorageVolObj;
-typedef virStorageVolObj *virStorageVolObjPtr;
 struct _virStorageVolObj {
     virObjectLockable parent;
 
-    virStorageVolDefPtr voldef;
+    virStorageVolDef *voldef;
 };
 
 typedef struct _virStorageVolObjList virStorageVolObjList;
-typedef virStorageVolObjList *virStorageVolObjListPtr;
 struct _virStorageVolObjList {
     virObjectRWLockable parent;
 
@@ -90,10 +88,10 @@ struct _virStoragePoolObj {
     bool autostart;
     unsigned int asyncjobs;
 
-    virStoragePoolDefPtr def;
-    virStoragePoolDefPtr newDef;
+    virStoragePoolDef *def;
+    virStoragePoolDef *newDef;
 
-    virStorageVolObjListPtr volumes;
+    virStorageVolObjList *volumes;
 };
 
 struct _virStoragePoolObjList {
@@ -124,10 +122,10 @@ virStorageVolObjOnceInit(void)
 VIR_ONCE_GLOBAL_INIT(virStorageVolObj);
 
 
-static virStorageVolObjPtr
+static virStorageVolObj *
 virStorageVolObjNew(void)
 {
-    virStorageVolObjPtr obj;
+    virStorageVolObj *obj;
 
     if (virStorageVolObjInitialize() < 0)
         return NULL;
@@ -141,7 +139,7 @@ virStorageVolObjNew(void)
 
 
 static void
-virStorageVolObjEndAPI(virStorageVolObjPtr *obj)
+virStorageVolObjEndAPI(virStorageVolObj **obj)
 {
     if (!*obj)
         return;
@@ -155,16 +153,16 @@ virStorageVolObjEndAPI(virStorageVolObjPtr *obj)
 static void
 virStorageVolObjDispose(void *opaque)
 {
-    virStorageVolObjPtr obj = opaque;
+    virStorageVolObj *obj = opaque;
 
     virStorageVolDefFree(obj->voldef);
 }
 
 
-static virStorageVolObjListPtr
+static virStorageVolObjList *
 virStorageVolObjListNew(void)
 {
-    virStorageVolObjListPtr vols;
+    virStorageVolObjList *vols;
 
     if (virStorageVolObjInitialize() < 0)
         return NULL;
@@ -186,7 +184,7 @@ virStorageVolObjListNew(void)
 static void
 virStorageVolObjListDispose(void *opaque)
 {
-    virStorageVolObjListPtr vols = opaque;
+    virStorageVolObjList *vols = opaque;
 
     virHashFree(vols->objsKey);
     virHashFree(vols->objsName);
@@ -209,10 +207,10 @@ virStoragePoolObjOnceInit(void)
 VIR_ONCE_GLOBAL_INIT(virStoragePoolObj);
 
 
-virStoragePoolObjPtr
+virStoragePoolObj *
 virStoragePoolObjNew(void)
 {
-    virStoragePoolObjPtr obj;
+    virStoragePoolObj *obj;
 
     if (virStoragePoolObjInitialize() < 0)
         return NULL;
@@ -232,7 +230,7 @@ virStoragePoolObjNew(void)
 
 
 void
-virStoragePoolObjEndAPI(virStoragePoolObjPtr *obj)
+virStoragePoolObjEndAPI(virStoragePoolObj **obj)
 {
     if (!*obj)
         return;
@@ -243,31 +241,31 @@ virStoragePoolObjEndAPI(virStoragePoolObjPtr *obj)
 }
 
 
-virStoragePoolDefPtr
-virStoragePoolObjGetDef(virStoragePoolObjPtr obj)
+virStoragePoolDef *
+virStoragePoolObjGetDef(virStoragePoolObj *obj)
 {
     return obj->def;
 }
 
 
 void
-virStoragePoolObjSetDef(virStoragePoolObjPtr obj,
-                        virStoragePoolDefPtr def)
+virStoragePoolObjSetDef(virStoragePoolObj *obj,
+                        virStoragePoolDef *def)
 {
     virStoragePoolDefFree(obj->def);
     obj->def = def;
 }
 
 
-virStoragePoolDefPtr
-virStoragePoolObjGetNewDef(virStoragePoolObjPtr obj)
+virStoragePoolDef *
+virStoragePoolObjGetNewDef(virStoragePoolObj *obj)
 {
     return obj->newDef;
 }
 
 
 void
-virStoragePoolObjDefUseNewDef(virStoragePoolObjPtr obj)
+virStoragePoolObjDefUseNewDef(virStoragePoolObj *obj)
 {
     virStoragePoolDefFree(obj->def);
     obj->def = g_steal_pointer(&obj->newDef);
@@ -275,14 +273,14 @@ virStoragePoolObjDefUseNewDef(virStoragePoolObjPtr obj)
 
 
 const char *
-virStoragePoolObjGetConfigFile(virStoragePoolObjPtr obj)
+virStoragePoolObjGetConfigFile(virStoragePoolObj *obj)
 {
     return obj->configFile;
 }
 
 
 void
-virStoragePoolObjSetConfigFile(virStoragePoolObjPtr obj,
+virStoragePoolObjSetConfigFile(virStoragePoolObj *obj,
                                char *configFile)
 {
     VIR_FREE(obj->configFile);
@@ -291,21 +289,21 @@ virStoragePoolObjSetConfigFile(virStoragePoolObjPtr obj,
 
 
 const char *
-virStoragePoolObjGetAutostartLink(virStoragePoolObjPtr obj)
+virStoragePoolObjGetAutostartLink(virStoragePoolObj *obj)
 {
     return obj->autostartLink;
 }
 
 
 bool
-virStoragePoolObjIsActive(virStoragePoolObjPtr obj)
+virStoragePoolObjIsActive(virStoragePoolObj *obj)
 {
     return obj->active;
 }
 
 
 void
-virStoragePoolObjSetActive(virStoragePoolObjPtr obj,
+virStoragePoolObjSetActive(virStoragePoolObj *obj,
                            bool active)
 {
     obj->active = active;
@@ -313,7 +311,7 @@ virStoragePoolObjSetActive(virStoragePoolObjPtr obj,
 
 
 void
-virStoragePoolObjSetStarting(virStoragePoolObjPtr obj,
+virStoragePoolObjSetStarting(virStoragePoolObj *obj,
                              bool starting)
 {
     obj->starting = starting;
@@ -321,14 +319,14 @@ virStoragePoolObjSetStarting(virStoragePoolObjPtr obj,
 
 
 bool
-virStoragePoolObjIsStarting(virStoragePoolObjPtr obj)
+virStoragePoolObjIsStarting(virStoragePoolObj *obj)
 {
     return obj->starting;
 }
 
 
 bool
-virStoragePoolObjIsAutostart(virStoragePoolObjPtr obj)
+virStoragePoolObjIsAutostart(virStoragePoolObj *obj)
 {
     if (!obj->configFile)
         return false;
@@ -338,7 +336,7 @@ virStoragePoolObjIsAutostart(virStoragePoolObjPtr obj)
 
 
 void
-virStoragePoolObjSetAutostart(virStoragePoolObjPtr obj,
+virStoragePoolObjSetAutostart(virStoragePoolObj *obj,
                               bool autostart)
 {
     obj->autostart = autostart;
@@ -346,21 +344,21 @@ virStoragePoolObjSetAutostart(virStoragePoolObjPtr obj,
 
 
 unsigned int
-virStoragePoolObjGetAsyncjobs(virStoragePoolObjPtr obj)
+virStoragePoolObjGetAsyncjobs(virStoragePoolObj *obj)
 {
     return obj->asyncjobs;
 }
 
 
 void
-virStoragePoolObjIncrAsyncjobs(virStoragePoolObjPtr obj)
+virStoragePoolObjIncrAsyncjobs(virStoragePoolObj *obj)
 {
     obj->asyncjobs++;
 }
 
 
 void
-virStoragePoolObjDecrAsyncjobs(virStoragePoolObjPtr obj)
+virStoragePoolObjDecrAsyncjobs(virStoragePoolObj *obj)
 {
     obj->asyncjobs--;
 }
@@ -369,7 +367,7 @@ virStoragePoolObjDecrAsyncjobs(virStoragePoolObjPtr obj)
 void
 virStoragePoolObjDispose(void *opaque)
 {
-    virStoragePoolObjPtr obj = opaque;
+    virStoragePoolObj *obj = opaque;
 
     virStoragePoolObjClearVols(obj);
     virObjectUnref(obj->volumes);
@@ -385,17 +383,17 @@ virStoragePoolObjDispose(void *opaque)
 void
 virStoragePoolObjListDispose(void *opaque)
 {
-    virStoragePoolObjListPtr pools = opaque;
+    virStoragePoolObjList *pools = opaque;
 
     virHashFree(pools->objs);
     virHashFree(pools->objsName);
 }
 
 
-virStoragePoolObjListPtr
+virStoragePoolObjList *
 virStoragePoolObjListNew(void)
 {
-    virStoragePoolObjListPtr pools;
+    virStoragePoolObjList *pools;
 
     if (virStoragePoolObjInitialize() < 0)
         return NULL;
@@ -423,7 +421,7 @@ virStoragePoolObjListForEachCb(void *payload,
                                const char *name G_GNUC_UNUSED,
                                void *opaque)
 {
-    virStoragePoolObjPtr obj = payload;
+    virStoragePoolObj *obj = payload;
     struct _virStoragePoolObjListForEachData *data = opaque;
 
     /* Grab a reference so that we don't rely only on references grabbed by
@@ -457,7 +455,7 @@ virStoragePoolObjListForEachCb(void *payload,
  *     AutoStart, or Reload) this is OK.
  */
 void
-virStoragePoolObjListForEach(virStoragePoolObjListPtr pools,
+virStoragePoolObjListForEach(virStoragePoolObjList *pools,
                              virStoragePoolObjListIterator iter,
                              const void *opaque)
 {
@@ -479,7 +477,7 @@ virStoragePoolObjListSearchCb(const void *payload,
                               const char *name G_GNUC_UNUSED,
                               const void *opaque)
 {
-    virStoragePoolObjPtr obj = (virStoragePoolObjPtr) payload;
+    virStoragePoolObj *obj = (virStoragePoolObj *) payload;
     struct _virStoragePoolObjListSearchData *data =
         (struct _virStoragePoolObjListSearchData *)opaque;
 
@@ -503,12 +501,12 @@ virStoragePoolObjListSearchCb(const void *payload,
  *
  * Returns a locked and reffed object when found and NULL when not found
  */
-virStoragePoolObjPtr
-virStoragePoolObjListSearch(virStoragePoolObjListPtr pools,
+virStoragePoolObj *
+virStoragePoolObjListSearch(virStoragePoolObjList *pools,
                             virStoragePoolObjListSearcher searcher,
                             const void *opaque)
 {
-    virStoragePoolObjPtr obj = NULL;
+    virStoragePoolObj *obj = NULL;
     struct _virStoragePoolObjListSearchData data = { .searcher = searcher,
                                                      .opaque = opaque };
 
@@ -521,8 +519,8 @@ virStoragePoolObjListSearch(virStoragePoolObjListPtr pools,
 
 
 void
-virStoragePoolObjRemove(virStoragePoolObjListPtr pools,
-                        virStoragePoolObjPtr obj)
+virStoragePoolObjRemove(virStoragePoolObjList *pools,
+                        virStoragePoolObj *obj)
 {
     char uuidstr[VIR_UUID_STRING_BUFLEN];
 
@@ -538,8 +536,8 @@ virStoragePoolObjRemove(virStoragePoolObjListPtr pools,
 }
 
 
-static virStoragePoolObjPtr
-virStoragePoolObjFindByUUIDLocked(virStoragePoolObjListPtr pools,
+static virStoragePoolObj *
+virStoragePoolObjFindByUUIDLocked(virStoragePoolObjList *pools,
                                   const unsigned char *uuid)
 {
     char uuidstr[VIR_UUID_STRING_BUFLEN];
@@ -559,11 +557,11 @@ virStoragePoolObjFindByUUIDLocked(virStoragePoolObjListPtr pools,
  *
  * Returns: Locked and reffed storage pool object or NULL if not found
  */
-virStoragePoolObjPtr
-virStoragePoolObjFindByUUID(virStoragePoolObjListPtr pools,
+virStoragePoolObj *
+virStoragePoolObjFindByUUID(virStoragePoolObjList *pools,
                             const unsigned char *uuid)
 {
-    virStoragePoolObjPtr obj;
+    virStoragePoolObj *obj;
 
     virObjectRWLockRead(pools);
     obj = virStoragePoolObjFindByUUIDLocked(pools, uuid);
@@ -575,8 +573,8 @@ virStoragePoolObjFindByUUID(virStoragePoolObjListPtr pools,
 }
 
 
-static virStoragePoolObjPtr
-virStoragePoolObjFindByNameLocked(virStoragePoolObjListPtr pools,
+static virStoragePoolObj *
+virStoragePoolObjFindByNameLocked(virStoragePoolObjList *pools,
                                   const char *name)
 {
     return virObjectRef(virHashLookup(pools->objsName, name));
@@ -592,11 +590,11 @@ virStoragePoolObjFindByNameLocked(virStoragePoolObjListPtr pools,
  *
  * Returns: Locked and reffed storage pool object or NULL if not found
  */
-virStoragePoolObjPtr
-virStoragePoolObjFindByName(virStoragePoolObjListPtr pools,
+virStoragePoolObj *
+virStoragePoolObjFindByName(virStoragePoolObjList *pools,
                             const char *name)
 {
-    virStoragePoolObjPtr obj;
+    virStoragePoolObj *obj;
 
     virObjectRWLockRead(pools);
     obj = virStoragePoolObjFindByNameLocked(pools, name);
@@ -608,9 +606,9 @@ virStoragePoolObjFindByName(virStoragePoolObjListPtr pools,
 }
 
 
-static virStoragePoolObjPtr
-virStoragePoolSourceFindDuplicateDevices(virStoragePoolObjPtr obj,
-                                         virStoragePoolDefPtr def)
+static virStoragePoolObj *
+virStoragePoolSourceFindDuplicateDevices(virStoragePoolObj *obj,
+                                         virStoragePoolDef *def)
 {
     size_t i, j;
 
@@ -626,7 +624,7 @@ virStoragePoolSourceFindDuplicateDevices(virStoragePoolObjPtr obj,
 
 
 void
-virStoragePoolObjClearVols(virStoragePoolObjPtr obj)
+virStoragePoolObjClearVols(virStoragePoolObj *obj)
 {
     if (!obj->volumes)
         return;
@@ -638,11 +636,11 @@ virStoragePoolObjClearVols(virStoragePoolObjPtr obj)
 
 
 int
-virStoragePoolObjAddVol(virStoragePoolObjPtr obj,
-                        virStorageVolDefPtr voldef)
+virStoragePoolObjAddVol(virStoragePoolObj *obj,
+                        virStorageVolDef *voldef)
 {
-    virStorageVolObjPtr volobj = NULL;
-    virStorageVolObjListPtr volumes = obj->volumes;
+    virStorageVolObj *volobj = NULL;
+    virStorageVolObjList *volumes = obj->volumes;
 
     virObjectRWLockWrite(volumes);
 
@@ -679,11 +677,11 @@ virStoragePoolObjAddVol(virStoragePoolObjPtr obj,
 
 
 void
-virStoragePoolObjRemoveVol(virStoragePoolObjPtr obj,
-                           virStorageVolDefPtr voldef)
+virStoragePoolObjRemoveVol(virStoragePoolObj *obj,
+                           virStorageVolDef *voldef)
 {
-    virStorageVolObjListPtr volumes = obj->volumes;
-    virStorageVolObjPtr volobj;
+    virStorageVolObjList *volumes = obj->volumes;
+    virStorageVolObj *volobj;
 
     virObjectRWLockWrite(volumes);
     volobj = virHashLookup(volumes->objsName, voldef->name);
@@ -708,7 +706,7 @@ virStoragePoolObjRemoveVol(virStoragePoolObjPtr obj,
 
 
 size_t
-virStoragePoolObjGetVolumesCount(virStoragePoolObjPtr obj)
+virStoragePoolObjGetVolumesCount(virStoragePoolObj *obj)
 {
     size_t nbElems;
 
@@ -731,7 +729,7 @@ virStoragePoolObjForEachVolumeCb(void *payload,
                                  void *opaque)
 {
     int ret = 0;
-    virStorageVolObjPtr volobj = payload;
+    virStorageVolObj *volobj = payload;
     struct _virStoragePoolObjForEachVolData *data = opaque;
 
     virObjectLock(volobj);
@@ -744,7 +742,7 @@ virStoragePoolObjForEachVolumeCb(void *payload,
 
 
 int
-virStoragePoolObjForEachVolume(virStoragePoolObjPtr obj,
+virStoragePoolObjForEachVolume(virStoragePoolObj *obj,
                                virStorageVolObjListIterator iter,
                                const void *opaque)
 {
@@ -769,7 +767,7 @@ virStoragePoolObjSearchVolumeCb(const void *payload,
                                 const char *name G_GNUC_UNUSED,
                                 const void *opaque)
 {
-    virStorageVolObjPtr volobj = (virStorageVolObjPtr) payload;
+    virStorageVolObj *volobj = (virStorageVolObj *) payload;
     struct _virStoragePoolObjSearchVolData *data =
         (struct _virStoragePoolObjSearchVolData *) opaque;
     int found = 0;
@@ -783,12 +781,12 @@ virStoragePoolObjSearchVolumeCb(const void *payload,
 }
 
 
-virStorageVolDefPtr
-virStoragePoolObjSearchVolume(virStoragePoolObjPtr obj,
+virStorageVolDef *
+virStoragePoolObjSearchVolume(virStoragePoolObj *obj,
                               virStorageVolObjListSearcher iter,
                               const void *opaque)
 {
-    virStorageVolObjPtr volobj;
+    virStorageVolObj *volobj;
     struct _virStoragePoolObjSearchVolData data = {
         .iter = iter, .opaque = opaque };
 
@@ -805,11 +803,11 @@ virStoragePoolObjSearchVolume(virStoragePoolObjPtr obj,
 }
 
 
-virStorageVolDefPtr
-virStorageVolDefFindByKey(virStoragePoolObjPtr obj,
+virStorageVolDef *
+virStorageVolDefFindByKey(virStoragePoolObj *obj,
                           const char *key)
 {
-    virStorageVolObjPtr volobj;
+    virStorageVolObj *volobj;
 
     virObjectRWLockRead(obj->volumes);
     volobj = virHashLookup(obj->volumes->objsKey, key);
@@ -821,11 +819,11 @@ virStorageVolDefFindByKey(virStoragePoolObjPtr obj,
 }
 
 
-virStorageVolDefPtr
-virStorageVolDefFindByPath(virStoragePoolObjPtr obj,
+virStorageVolDef *
+virStorageVolDefFindByPath(virStoragePoolObj *obj,
                            const char *path)
 {
-    virStorageVolObjPtr volobj;
+    virStorageVolObj *volobj;
 
     virObjectRWLockRead(obj->volumes);
     volobj = virHashLookup(obj->volumes->objsPath, path);
@@ -837,11 +835,11 @@ virStorageVolDefFindByPath(virStoragePoolObjPtr obj,
 }
 
 
-virStorageVolDefPtr
-virStorageVolDefFindByName(virStoragePoolObjPtr obj,
+virStorageVolDef *
+virStorageVolDefFindByName(virStoragePoolObj *obj,
                            const char *name)
 {
-    virStorageVolObjPtr volobj;
+    virStorageVolObj *volobj;
 
     virObjectRWLockRead(obj->volumes);
     volobj = virHashLookup(obj->volumes->objsName, name);
@@ -856,7 +854,7 @@ virStorageVolDefFindByName(virStoragePoolObjPtr obj,
 struct _virStorageVolObjCountData {
     virConnectPtr conn;
     virStoragePoolVolumeACLFilter filter;
-    virStoragePoolDefPtr pooldef;
+    virStoragePoolDef *pooldef;
     int count;
 };
 
@@ -866,7 +864,7 @@ virStoragePoolObjNumOfVolumesCb(void *payload,
                                 const char *name G_GNUC_UNUSED,
                                 void *opaque)
 {
-    virStorageVolObjPtr volobj = payload;
+    virStorageVolObj *volobj = payload;
     struct _virStorageVolObjCountData *data = opaque;
 
     virObjectLock(volobj);
@@ -884,11 +882,11 @@ virStoragePoolObjNumOfVolumesCb(void *payload,
 
 
 int
-virStoragePoolObjNumOfVolumes(virStoragePoolObjPtr obj,
+virStoragePoolObjNumOfVolumes(virStoragePoolObj *obj,
                               virConnectPtr conn,
                               virStoragePoolVolumeACLFilter filter)
 {
-    virStorageVolObjListPtr volumes = obj->volumes;
+    virStorageVolObjList *volumes = obj->volumes;
     struct _virStorageVolObjCountData data = {
         .conn = conn, .filter = filter, .pooldef = obj->def, .count = 0 };
 
@@ -903,7 +901,7 @@ virStoragePoolObjNumOfVolumes(virStoragePoolObjPtr obj,
 struct _virStorageVolObjNameData {
     virConnectPtr conn;
     virStoragePoolVolumeACLFilter filter;
-    virStoragePoolDefPtr pooldef;
+    virStoragePoolDef *pooldef;
     bool error;
     int nnames;
     int maxnames;
@@ -915,7 +913,7 @@ virStoragePoolObjVolumeGetNamesCb(void *payload,
                                   const char *name G_GNUC_UNUSED,
                                   void *opaque)
 {
-    virStorageVolObjPtr volobj = payload;
+    virStorageVolObj *volobj = payload;
     struct _virStorageVolObjNameData *data = opaque;
 
     if (data->error)
@@ -942,13 +940,13 @@ virStoragePoolObjVolumeGetNamesCb(void *payload,
 
 
 int
-virStoragePoolObjVolumeGetNames(virStoragePoolObjPtr obj,
+virStoragePoolObjVolumeGetNames(virStoragePoolObj *obj,
                                 virConnectPtr conn,
                                 virStoragePoolVolumeACLFilter filter,
                                 char **const names,
                                 int maxnames)
 {
-    virStorageVolObjListPtr volumes = obj->volumes;
+    virStorageVolObjList *volumes = obj->volumes;
     struct _virStorageVolObjNameData data = {
         .conn = conn, .filter = filter, .pooldef = obj->def, .error = false,
         .nnames = 0, .maxnames = maxnames, .names = names };
@@ -970,11 +968,10 @@ virStoragePoolObjVolumeGetNames(virStoragePoolObjPtr obj,
 
 
 typedef struct _virStoragePoolObjVolumeListExportData virStoragePoolObjVolumeListExportData;
-typedef virStoragePoolObjVolumeListExportData *virStoragePoolObjVolumeListExportDataPtr;
 struct _virStoragePoolObjVolumeListExportData {
     virConnectPtr conn;
     virStoragePoolVolumeACLFilter filter;
-    virStoragePoolDefPtr pooldef;
+    virStoragePoolDef *pooldef;
     bool error;
     int nvols;
     virStorageVolPtr *vols;
@@ -985,8 +982,8 @@ virStoragePoolObjVolumeListExportCallback(void *payload,
                                           const char *name G_GNUC_UNUSED,
                                           void *opaque)
 {
-    virStorageVolObjPtr volobj = payload;
-    virStoragePoolObjVolumeListExportDataPtr data = opaque;
+    virStorageVolObj *volobj = payload;
+    virStoragePoolObjVolumeListExportData *data = opaque;
     virStorageVolPtr vol = NULL;
 
     if (data->error)
@@ -1018,11 +1015,11 @@ virStoragePoolObjVolumeListExportCallback(void *payload,
 
 int
 virStoragePoolObjVolumeListExport(virConnectPtr conn,
-                                  virStoragePoolObjPtr obj,
+                                  virStoragePoolObj *obj,
                                   virStorageVolPtr **vols,
                                   virStoragePoolVolumeACLFilter filter)
 {
-    virStorageVolObjListPtr volumes = obj->volumes;
+    virStorageVolObjList *volumes = obj->volumes;
     virStoragePoolObjVolumeListExportData data = {
         .conn = conn, .filter = filter, .pooldef = obj->def, .error = false,
         .nvols = 0, .vols = NULL };
@@ -1055,8 +1052,8 @@ virStoragePoolObjVolumeListExport(virConnectPtr conn,
 
 /*
  * virStoragePoolObjIsDuplicate:
- * @doms : virStoragePoolObjListPtr to search
- * @def  : virStoragePoolDefPtr definition of pool to lookup
+ * @doms : virStoragePoolObjList * to search
+ * @def  : virStoragePoolDef * definition of pool to lookup
  * @check_active: If true, ensure that pool is not active
  * @objRet: returned pool object
  *
@@ -1067,13 +1064,13 @@ virStoragePoolObjVolumeListExport(virConnectPtr conn,
  *          1 if pool is a duplicate (name and UUID match)
  */
 static int
-virStoragePoolObjIsDuplicate(virStoragePoolObjListPtr pools,
-                             virStoragePoolDefPtr def,
+virStoragePoolObjIsDuplicate(virStoragePoolObjList *pools,
+                             virStoragePoolDef *def,
                              bool check_active,
-                             virStoragePoolObjPtr *objRet)
+                             virStoragePoolObj **objRet)
 {
     int ret = -1;
-    virStoragePoolObjPtr obj = NULL;
+    virStoragePoolObj *obj = NULL;
 
     /* See if a Pool with matching UUID already exists */
     obj = virStoragePoolObjFindByUUIDLocked(pools, def->uuid);
@@ -1133,7 +1130,7 @@ virStoragePoolObjIsDuplicate(virStoragePoolObjListPtr pools,
 
 
 static int
-getSCSIHostNumber(virStorageAdapterSCSIHostPtr scsi_host,
+getSCSIHostNumber(virStorageAdapterSCSIHost *scsi_host,
                   unsigned int *hostnum)
 {
     int ret = -1;
@@ -1141,7 +1138,7 @@ getSCSIHostNumber(virStorageAdapterSCSIHostPtr scsi_host,
     char *name = NULL;
 
     if (scsi_host->has_parent) {
-        virPCIDeviceAddressPtr addr = &scsi_host->parentaddr;
+        virPCIDeviceAddress *addr = &scsi_host->parentaddr;
         unsigned int unique_id = scsi_host->unique_id;
 
         if (!(name = virSCSIHostGetNameByParentaddr(addr->domain,
@@ -1190,7 +1187,7 @@ virStorageIsSameHostnum(const char *name,
  *         fc_adapter host# and the scsi_host host#
  */
 static bool
-matchFCHostToSCSIHost(virStorageAdapterFCHostPtr fchost,
+matchFCHostToSCSIHost(virStorageAdapterFCHost *fchost,
                       unsigned int scsi_hostnum)
 {
     virConnectPtr conn = NULL;
@@ -1259,11 +1256,11 @@ matchFCHostToSCSIHost(virStorageAdapterFCHostPtr fchost,
 
 
 static bool
-matchSCSIAdapterParent(virStorageAdapterSCSIHostPtr pool_scsi_host,
-                       virStorageAdapterSCSIHostPtr def_scsi_host)
+matchSCSIAdapterParent(virStorageAdapterSCSIHost *pool_scsi_host,
+                       virStorageAdapterSCSIHost *def_scsi_host)
 {
-    virPCIDeviceAddressPtr pooladdr = &pool_scsi_host->parentaddr;
-    virPCIDeviceAddressPtr defaddr = &def_scsi_host->parentaddr;
+    virPCIDeviceAddress *pooladdr = &pool_scsi_host->parentaddr;
+    virPCIDeviceAddress *defaddr = &def_scsi_host->parentaddr;
 
     if (pooladdr->domain == defaddr->domain &&
         pooladdr->bus == defaddr->bus &&
@@ -1277,8 +1274,8 @@ matchSCSIAdapterParent(virStorageAdapterSCSIHostPtr pool_scsi_host,
 
 
 static bool
-virStoragePoolSourceMatchSingleHost(virStoragePoolSourcePtr poolsrc,
-                                    virStoragePoolSourcePtr defsrc)
+virStoragePoolSourceMatchSingleHost(virStoragePoolSource *poolsrc,
+                                    virStoragePoolSource *defsrc)
 {
     if (poolsrc->nhost != 1 && defsrc->nhost != 1)
         return false;
@@ -1292,11 +1289,11 @@ virStoragePoolSourceMatchSingleHost(virStoragePoolSourcePtr poolsrc,
 
 
 static bool
-virStoragePoolSourceISCSIMatch(virStoragePoolObjPtr obj,
-                               virStoragePoolDefPtr def)
+virStoragePoolSourceISCSIMatch(virStoragePoolObj *obj,
+                               virStoragePoolDef *def)
 {
-    virStoragePoolSourcePtr poolsrc = &obj->def->source;
-    virStoragePoolSourcePtr defsrc = &def->source;
+    virStoragePoolSource *poolsrc = &obj->def->source;
+    virStoragePoolSource *defsrc = &def->source;
 
     /* NB: Do not check the source host name */
     if (STRNEQ_NULLABLE(poolsrc->initiator.iqn, defsrc->initiator.iqn))
@@ -1306,9 +1303,9 @@ virStoragePoolSourceISCSIMatch(virStoragePoolObjPtr obj,
 }
 
 
-static virStoragePoolObjPtr
-virStoragePoolObjSourceMatchTypeDIR(virStoragePoolObjPtr obj,
-                                    virStoragePoolDefPtr def)
+static virStoragePoolObj *
+virStoragePoolObjSourceMatchTypeDIR(virStoragePoolObj *obj,
+                                    virStoragePoolDef *def)
 {
     if (obj->def->type == VIR_STORAGE_POOL_DIR) {
         if (STREQ(obj->def->target.path, def->target.path))
@@ -1330,16 +1327,16 @@ virStoragePoolObjSourceMatchTypeDIR(virStoragePoolObjPtr obj,
 }
 
 
-static virStoragePoolObjPtr
-virStoragePoolObjSourceMatchTypeISCSI(virStoragePoolObjPtr obj,
-                                      virStoragePoolDefPtr def)
+static virStoragePoolObj *
+virStoragePoolObjSourceMatchTypeISCSI(virStoragePoolObj *obj,
+                                      virStoragePoolDef *def)
 {
-    virStorageAdapterPtr pool_adapter = &obj->def->source.adapter;
-    virStorageAdapterPtr def_adapter = &def->source.adapter;
-    virStorageAdapterSCSIHostPtr pool_scsi_host;
-    virStorageAdapterSCSIHostPtr def_scsi_host;
-    virStorageAdapterFCHostPtr pool_fchost;
-    virStorageAdapterFCHostPtr def_fchost;
+    virStorageAdapter *pool_adapter = &obj->def->source.adapter;
+    virStorageAdapter *def_adapter = &def->source.adapter;
+    virStorageAdapterSCSIHost *pool_scsi_host;
+    virStorageAdapterSCSIHost *def_scsi_host;
+    virStorageAdapterFCHost *pool_fchost;
+    virStorageAdapterFCHost *def_fchost;
     unsigned int pool_hostnum;
     unsigned int def_hostnum;
     unsigned int scsi_hostnum;
@@ -1395,11 +1392,11 @@ virStoragePoolObjSourceMatchTypeISCSI(virStoragePoolObjPtr obj,
 }
 
 
-static virStoragePoolObjPtr
-virStoragePoolObjSourceMatchTypeDEVICE(virStoragePoolObjPtr obj,
-                                       virStoragePoolDefPtr def)
+static virStoragePoolObj *
+virStoragePoolObjSourceMatchTypeDEVICE(virStoragePoolObj *obj,
+                                       virStoragePoolDef *def)
 {
-    virStoragePoolObjPtr matchobj = NULL;
+    virStoragePoolObj *matchobj = NULL;
 
     if (obj->def->type == VIR_STORAGE_POOL_ISCSI) {
         if (def->type != VIR_STORAGE_POOL_ISCSI)
@@ -1424,7 +1421,7 @@ virStoragePoolObjSourceMatchTypeDEVICE(virStoragePoolObjPtr obj,
 
 
 struct _virStoragePoolObjFindDuplicateData {
-    virStoragePoolDefPtr def;
+    virStoragePoolDef *def;
 };
 
 static int
@@ -1432,7 +1429,7 @@ virStoragePoolObjSourceFindDuplicateCb(const void *payload,
                                        const char *name G_GNUC_UNUSED,
                                        const void *opaque)
 {
-    virStoragePoolObjPtr obj = (virStoragePoolObjPtr) payload;
+    virStoragePoolObj *obj = (virStoragePoolObj *) payload;
     struct _virStoragePoolObjFindDuplicateData *data =
         (struct _virStoragePoolObjFindDuplicateData *) opaque;
 
@@ -1500,11 +1497,11 @@ virStoragePoolObjSourceFindDuplicateCb(const void *payload,
 
 
 static int
-virStoragePoolObjSourceFindDuplicate(virStoragePoolObjListPtr pools,
-                                     virStoragePoolDefPtr def)
+virStoragePoolObjSourceFindDuplicate(virStoragePoolObjList *pools,
+                                     virStoragePoolDef *def)
 {
     struct _virStoragePoolObjFindDuplicateData data = {.def = def};
-    virStoragePoolObjPtr obj = NULL;
+    virStoragePoolObj *obj = NULL;
 
     obj = virHashSearch(pools->objs, virStoragePoolObjSourceFindDuplicateCb,
                         &data, NULL);
@@ -1521,8 +1518,8 @@ virStoragePoolObjSourceFindDuplicate(virStoragePoolObjListPtr pools,
 
 
 static void
-virStoragePoolObjAssignDef(virStoragePoolObjPtr obj,
-                           virStoragePoolDefPtr def,
+virStoragePoolObjAssignDef(virStoragePoolObj *obj,
+                           virStoragePoolDef *def,
                            unsigned int flags)
 {
     if (virStoragePoolObjIsActive(obj) ||
@@ -1559,12 +1556,12 @@ virStoragePoolObjAssignDef(virStoragePoolObjPtr obj,
  *
  * Returns locked and reffed object pointer or NULL on error
  */
-virStoragePoolObjPtr
-virStoragePoolObjListAdd(virStoragePoolObjListPtr pools,
-                         virStoragePoolDefPtr def,
+virStoragePoolObj *
+virStoragePoolObjListAdd(virStoragePoolObjList *pools,
+                         virStoragePoolDef *def,
                          unsigned int flags)
 {
-    virStoragePoolObjPtr obj = NULL;
+    virStoragePoolObj *obj = NULL;
     char uuidstr[VIR_UUID_STRING_BUFLEN];
     int rc;
 
@@ -1609,13 +1606,13 @@ virStoragePoolObjListAdd(virStoragePoolObjListPtr pools,
 }
 
 
-static virStoragePoolObjPtr
-virStoragePoolObjLoad(virStoragePoolObjListPtr pools,
+static virStoragePoolObj *
+virStoragePoolObjLoad(virStoragePoolObjList *pools,
                       const char *file,
                       const char *path,
                       const char *autostartLink)
 {
-    virStoragePoolObjPtr obj;
+    virStoragePoolObj *obj;
     g_autoptr(virStoragePoolDef) def = NULL;
 
     if (!(def = virStoragePoolDefParseFile(path)))
@@ -1645,13 +1642,13 @@ virStoragePoolObjLoad(virStoragePoolObjListPtr pools,
 }
 
 
-static virStoragePoolObjPtr
-virStoragePoolObjLoadState(virStoragePoolObjListPtr pools,
+static virStoragePoolObj *
+virStoragePoolObjLoadState(virStoragePoolObjList *pools,
                            const char *stateDir,
                            const char *name)
 {
     char *stateFile = NULL;
-    virStoragePoolObjPtr obj = NULL;
+    virStoragePoolObj *obj = NULL;
     xmlDocPtr xml = NULL;
     xmlXPathContextPtr ctxt = NULL;
     xmlNodePtr node = NULL;
@@ -1703,7 +1700,7 @@ virStoragePoolObjLoadState(virStoragePoolObjListPtr pools,
 
 
 int
-virStoragePoolObjLoadAllState(virStoragePoolObjListPtr pools,
+virStoragePoolObjLoadAllState(virStoragePoolObjList *pools,
                               const char *stateDir)
 {
     g_autoptr(DIR) dir = NULL;
@@ -1715,7 +1712,7 @@ virStoragePoolObjLoadAllState(virStoragePoolObjListPtr pools,
         return rc;
 
     while ((ret = virDirRead(dir, &entry, stateDir)) > 0) {
-        virStoragePoolObjPtr obj;
+        virStoragePoolObj *obj;
 
         if (!virStringStripSuffix(entry->d_name, ".xml"))
             continue;
@@ -1730,7 +1727,7 @@ virStoragePoolObjLoadAllState(virStoragePoolObjListPtr pools,
 
 
 int
-virStoragePoolObjLoadAllConfigs(virStoragePoolObjListPtr pools,
+virStoragePoolObjLoadAllConfigs(virStoragePoolObjList *pools,
                                 const char *configDir,
                                 const char *autostartDir)
 {
@@ -1745,7 +1742,7 @@ virStoragePoolObjLoadAllConfigs(virStoragePoolObjListPtr pools,
     while ((ret = virDirRead(dir, &entry, configDir)) > 0) {
         char *path;
         char *autostartLink;
-        virStoragePoolObjPtr obj;
+        virStoragePoolObj *obj;
 
         if (!virStringHasSuffix(entry->d_name, ".xml"))
             continue;
@@ -1771,9 +1768,9 @@ virStoragePoolObjLoadAllConfigs(virStoragePoolObjListPtr pools,
 
 
 int
-virStoragePoolObjSaveDef(virStorageDriverStatePtr driver,
-                         virStoragePoolObjPtr obj,
-                         virStoragePoolDefPtr def)
+virStoragePoolObjSaveDef(virStorageDriverState *driver,
+                         virStoragePoolObj *obj,
+                         virStoragePoolDef *def)
 {
     if (!obj->configFile) {
         if (g_mkdir_with_parents(driver->configDir, 0777) < 0) {
@@ -1800,7 +1797,7 @@ virStoragePoolObjSaveDef(virStorageDriverStatePtr driver,
 
 
 int
-virStoragePoolObjDeleteDef(virStoragePoolObjPtr obj)
+virStoragePoolObjDeleteDef(virStoragePoolObj *obj)
 {
     if (!obj->configFile) {
         virReportError(VIR_ERR_INTERNAL_ERROR,
@@ -1832,7 +1829,7 @@ virStoragePoolObjNumOfStoragePoolsCb(void *payload,
                                      const char *name G_GNUC_UNUSED,
                                      void *opaque)
 {
-    virStoragePoolObjPtr obj = payload;
+    virStoragePoolObj *obj = payload;
     struct _virStoragePoolCountData *data = opaque;
 
     virObjectLock(obj);
@@ -1852,7 +1849,7 @@ virStoragePoolObjNumOfStoragePoolsCb(void *payload,
 
 
 int
-virStoragePoolObjNumOfStoragePools(virStoragePoolObjListPtr pools,
+virStoragePoolObjNumOfStoragePools(virStoragePoolObjList *pools,
                                    virConnectPtr conn,
                                    bool wantActive,
                                    virStoragePoolObjListACLFilter filter)
@@ -1884,7 +1881,7 @@ virStoragePoolObjGetNamesCb(void *payload,
                             const char *name G_GNUC_UNUSED,
                             void *opaque)
 {
-    virStoragePoolObjPtr obj = payload;
+    virStoragePoolObj *obj = payload;
     struct _virStoragePoolNameData *data = opaque;
 
     if (data->error)
@@ -1913,7 +1910,7 @@ virStoragePoolObjGetNamesCb(void *payload,
 
 
 int
-virStoragePoolObjGetNames(virStoragePoolObjListPtr pools,
+virStoragePoolObjGetNames(virStoragePoolObjList *pools,
                           virConnectPtr conn,
                           bool wantActive,
                           virStoragePoolObjListACLFilter filter,
@@ -1942,7 +1939,7 @@ virStoragePoolObjGetNames(virStoragePoolObjListPtr pools,
 
 #define MATCH(FLAG) (flags & (FLAG))
 static bool
-virStoragePoolObjMatch(virStoragePoolObjPtr obj,
+virStoragePoolObjMatch(virStoragePoolObj *obj,
                        unsigned int flags)
 {
     /* filter by active state */
@@ -2008,7 +2005,6 @@ virStoragePoolObjMatch(virStoragePoolObjPtr obj,
 
 
 typedef struct _virStoragePoolObjListExportData virStoragePoolObjListExportData;
-typedef virStoragePoolObjListExportData *virStoragePoolObjListExportDataPtr;
 struct _virStoragePoolObjListExportData {
     virConnectPtr conn;
     virStoragePoolObjListACLFilter filter;
@@ -2027,8 +2023,8 @@ virStoragePoolObjListExportCallback(void *payload,
                                     const char *name G_GNUC_UNUSED,
                                     void *opaque)
 {
-    virStoragePoolObjPtr obj = payload;
-    virStoragePoolObjListExportDataPtr data = opaque;
+    virStoragePoolObj *obj = payload;
+    virStoragePoolObjListExportData *data = opaque;
     virStoragePoolPtr pool = NULL;
 
     if (data->error)
@@ -2061,7 +2057,7 @@ virStoragePoolObjListExportCallback(void *payload,
 
 int
 virStoragePoolObjListExport(virConnectPtr conn,
-                            virStoragePoolObjListPtr poolobjs,
+                            virStoragePoolObjList *poolobjs,
                             virStoragePoolPtr **pools,
                             virStoragePoolObjListFilter filter,
                             unsigned int flags)
