@@ -1046,7 +1046,6 @@ int qemuMonitorBlockCommit(qemuMonitor *mon,
                            const char *backingName,
                            unsigned long long bandwidth)
     ATTRIBUTE_NONNULL(2);
-bool qemuMonitorSupportsActiveCommit(qemuMonitor *mon);
 char *qemuMonitorDiskNameLookup(qemuMonitor *mon,
                                 const char *device,
                                 virStorageSource *top,
@@ -1240,8 +1239,6 @@ qemuMonitorCPUModelInfoCopy(const qemuMonitorCPUModelInfo *orig);
 
 int qemuMonitorGetCommands(qemuMonitor *mon,
                            char ***commands);
-int qemuMonitorGetEvents(qemuMonitor *mon,
-                         char ***events);
 GHashTable *qemuMonitorGetCommandLineOptions(qemuMonitor *mon);
 
 int qemuMonitorGetKVMState(qemuMonitor *mon,
