@@ -31,6 +31,7 @@
 #include "virutil.h"
 #include "virbuffer.h"
 #include "virenum.h"
+#include "virbitmap.h"
 
 #if WITH_YAJL
 # include <yajl/yajl_gen.h>
@@ -44,28 +45,25 @@
 VIR_LOG_INIT("util.json");
 
 typedef struct _virJSONObject virJSONObject;
-typedef virJSONObject *virJSONObjectPtr;
 
 typedef struct _virJSONObjectPair virJSONObjectPair;
-typedef virJSONObjectPair *virJSONObjectPairPtr;
 
 typedef struct _virJSONArray virJSONArray;
-typedef virJSONArray *virJSONArrayPtr;
 
 
 struct _virJSONObjectPair {
     char *key;
-    virJSONValuePtr value;
+    virJSONValue *value;
 };
 
 struct _virJSONObject {
     size_t npairs;
-    virJSONObjectPairPtr pairs;
+    virJSONObjectPair *pairs;
 };
 
 struct _virJSONArray {
     size_t nvalues;
-    virJSONValuePtr *values;
+    virJSONValue **values;
 };
 
 struct _virJSONValue {
@@ -82,17 +80,15 @@ struct _virJSONValue {
 
 
 typedef struct _virJSONParserState virJSONParserState;
-typedef virJSONParserState *virJSONParserStatePtr;
 struct _virJSONParserState {
-    virJSONValuePtr value;
+    virJSONValue *value;
     char *key;
 };
 
 typedef struct _virJSONParser virJSONParser;
-typedef virJSONParser *virJSONParserPtr;
 struct _virJSONParser {
-    virJSONValuePtr head;
-    virJSONParserStatePtr state;
+    virJSONValue *head;
+    virJSONParserState *state;
     size_t nstate;
     int wrap;
 };
@@ -141,8 +137,8 @@ virJSONValueGetType(const virJSONValue *value)
  * d: double precision floating point number
  * n: json null value
  *
- * The following two cases take a pointer to a pointer to a virJSONValuePtr. The
- * pointer is cleared when the virJSONValuePtr is stolen into the object.
+ * The following two cases take a pointer to a pointer to a virJSONValue *. The
+ * pointer is cleared when the virJSONValue *is stolen into the object.
  * a: json object, must be non-NULL
  * A: json object, omitted if NULL
  *
@@ -155,7 +151,7 @@ virJSONValueGetType(const virJSONValue *value)
  * in case of no error but nothing was filled.
  */
 int
-virJSONValueObjectAddVArgs(virJSONValuePtr obj,
+virJSONValueObjectAddVArgs(virJSONValue *obj,
                            va_list args)
 {
     char type;
@@ -286,7 +282,7 @@ virJSONValueObjectAddVArgs(virJSONValuePtr obj,
 
         case 'A':
         case 'a': {
-            virJSONValuePtr *val = va_arg(args, virJSONValuePtr *);
+            virJSONValue **val = va_arg(args, virJSONValue **);
 
             if (!(*val)) {
                 if (type == 'A')
@@ -303,8 +299,9 @@ virJSONValueObjectAddVArgs(virJSONValuePtr obj,
 
         case 'M':
         case 'm': {
-            virBitmapPtr map = va_arg(args, virBitmapPtr);
-            g_autoptr(virJSONValue) jsonMap = NULL;
+            virBitmap *map = va_arg(args, virBitmap *);
+            g_autoptr(virJSONValue) jsonMap = virJSONValueNewArray();
+            ssize_t pos = -1;
 
             if (!map) {
                 if (type == 'M')
@@ -316,8 +313,12 @@ virJSONValueObjectAddVArgs(virJSONValuePtr obj,
                 return -1;
             }
 
-            if (!(jsonMap = virJSONValueNewArrayFromBitmap(map)))
-                return -1;
+            while ((pos = virBitmapNextSetBit(map, pos)) > -1) {
+                g_autoptr(virJSONValue) newelem = virJSONValueNewNumberLong(pos);
+
+                if (virJSONValueArrayAppend(jsonMap, &newelem) < 0)
+                    return -1;
+            }
 
             if ((rc = virJSONValueObjectAppend(obj, key, &jsonMap)) < 0)
                 return -1;
@@ -342,7 +343,7 @@ virJSONValueObjectAddVArgs(virJSONValuePtr obj,
 
 
 int
-virJSONValueObjectAdd(virJSONValuePtr obj, ...)
+virJSONValueObjectAdd(virJSONValue *obj, ...)
 {
     va_list args;
     int ret;
@@ -356,7 +357,7 @@ virJSONValueObjectAdd(virJSONValuePtr obj, ...)
 
 
 int
-virJSONValueObjectCreateVArgs(virJSONValuePtr *obj,
+virJSONValueObjectCreateVArgs(virJSONValue **obj,
                               va_list args)
 {
     int ret;
@@ -374,7 +375,7 @@ virJSONValueObjectCreateVArgs(virJSONValuePtr *obj,
 
 
 int
-virJSONValueObjectCreate(virJSONValuePtr *obj, ...)
+virJSONValueObjectCreate(virJSONValue **obj, ...)
 {
     va_list args;
     int ret;
@@ -388,7 +389,7 @@ virJSONValueObjectCreate(virJSONValuePtr *obj, ...)
 
 
 void
-virJSONValueFree(virJSONValuePtr value)
+virJSONValueFree(virJSONValue *value)
 {
     size_t i;
     if (!value)
@@ -429,10 +430,10 @@ virJSONValueHashFree(void *opaque)
 }
 
 
-virJSONValuePtr
+virJSONValue *
 virJSONValueNewString(const char *data)
 {
-    virJSONValuePtr val;
+    virJSONValue *val;
 
     if (!data)
         return virJSONValueNewNull();
@@ -446,11 +447,11 @@ virJSONValueNewString(const char *data)
 }
 
 
-virJSONValuePtr
+virJSONValue *
 virJSONValueNewStringLen(const char *data,
                          size_t length)
 {
-    virJSONValuePtr val;
+    virJSONValue *val;
 
     if (!data)
         return virJSONValueNewNull();
@@ -471,10 +472,10 @@ virJSONValueNewStringLen(const char *data,
  * Creates a new virJSONValue of VIR_JSON_TYPE_NUMBER type. Note that this
  * function takes ownership of @data.
  */
-static virJSONValuePtr
+static virJSONValue *
 virJSONValueNewNumber(char *data)
 {
-    virJSONValuePtr val;
+    virJSONValue *val;
 
     val = g_new0(virJSONValue, 1);
 
@@ -485,35 +486,35 @@ virJSONValueNewNumber(char *data)
 }
 
 
-virJSONValuePtr
+virJSONValue *
 virJSONValueNewNumberInt(int data)
 {
     return virJSONValueNewNumber(g_strdup_printf("%i", data));
 }
 
 
-virJSONValuePtr
+virJSONValue *
 virJSONValueNewNumberUint(unsigned int data)
 {
     return virJSONValueNewNumber(g_strdup_printf("%u", data));
 }
 
 
-virJSONValuePtr
+virJSONValue *
 virJSONValueNewNumberLong(long long data)
 {
     return virJSONValueNewNumber(g_strdup_printf("%lld", data));
 }
 
 
-virJSONValuePtr
+virJSONValue *
 virJSONValueNewNumberUlong(unsigned long long data)
 {
     return virJSONValueNewNumber(g_strdup_printf("%llu", data));
 }
 
 
-virJSONValuePtr
+virJSONValue *
 virJSONValueNewNumberDouble(double data)
 {
     char *str = NULL;
@@ -523,10 +524,10 @@ virJSONValueNewNumberDouble(double data)
 }
 
 
-virJSONValuePtr
+virJSONValue *
 virJSONValueNewBoolean(int boolean_)
 {
-    virJSONValuePtr val;
+    virJSONValue *val;
 
     val = g_new0(virJSONValue, 1);
 
@@ -537,10 +538,10 @@ virJSONValueNewBoolean(int boolean_)
 }
 
 
-virJSONValuePtr
+virJSONValue *
 virJSONValueNewNull(void)
 {
-    virJSONValuePtr val;
+    virJSONValue *val;
 
     val = g_new0(virJSONValue, 1);
 
@@ -550,10 +551,10 @@ virJSONValueNewNull(void)
 }
 
 
-virJSONValuePtr
+virJSONValue *
 virJSONValueNewArray(void)
 {
-    virJSONValuePtr val = g_new0(virJSONValue, 1);
+    virJSONValue *val = g_new0(virJSONValue, 1);
 
     val->type = VIR_JSON_TYPE_ARRAY;
 
@@ -561,10 +562,10 @@ virJSONValueNewArray(void)
 }
 
 
-virJSONValuePtr
+virJSONValue *
 virJSONValueNewObject(void)
 {
-    virJSONValuePtr val = g_new0(virJSONValue, 1);
+    virJSONValue *val = g_new0(virJSONValue, 1);
 
     val->type = VIR_JSON_TYPE_OBJECT;
 
@@ -573,9 +574,9 @@ virJSONValueNewObject(void)
 
 
 static int
-virJSONValueObjectInsert(virJSONValuePtr object,
+virJSONValueObjectInsert(virJSONValue *object,
                          const char *key,
-                         virJSONValuePtr *value,
+                         virJSONValue **value,
                          bool prepend)
 {
     virJSONObjectPair pair = { NULL, *value };
@@ -611,21 +612,21 @@ virJSONValueObjectInsert(virJSONValuePtr object,
 
 
 int
-virJSONValueObjectAppend(virJSONValuePtr object,
+virJSONValueObjectAppend(virJSONValue *object,
                          const char *key,
-                         virJSONValuePtr *value)
+                         virJSONValue **value)
 {
     return virJSONValueObjectInsert(object, key, value, false);
 }
 
 
 static int
-virJSONValueObjectInsertString(virJSONValuePtr object,
+virJSONValueObjectInsertString(virJSONValue *object,
                                const char *key,
                                const char *value,
                                bool prepend)
 {
-    virJSONValuePtr jvalue = virJSONValueNewString(value);
+    virJSONValue *jvalue = virJSONValueNewString(value);
     if (!jvalue)
         return -1;
     if (virJSONValueObjectInsert(object, key, &jvalue, prepend) < 0)
@@ -635,7 +636,7 @@ virJSONValueObjectInsertString(virJSONValuePtr object,
 
 
 int
-virJSONValueObjectAppendString(virJSONValuePtr object,
+virJSONValueObjectAppendString(virJSONValue *object,
                                const char *key,
                                const char *value)
 {
@@ -644,7 +645,7 @@ virJSONValueObjectAppendString(virJSONValuePtr object,
 
 
 int
-virJSONValueObjectAppendStringPrintf(virJSONValuePtr object,
+virJSONValueObjectAppendStringPrintf(virJSONValue *object,
                                      const char *key,
                                      const char *fmt,
                                      ...)
@@ -661,7 +662,7 @@ virJSONValueObjectAppendStringPrintf(virJSONValuePtr object,
 
 
 int
-virJSONValueObjectPrependString(virJSONValuePtr object,
+virJSONValueObjectPrependString(virJSONValue *object,
                                 const char *key,
                                 const char *value)
 {
@@ -670,7 +671,7 @@ virJSONValueObjectPrependString(virJSONValuePtr object,
 
 
 int
-virJSONValueObjectAppendNumberInt(virJSONValuePtr object,
+virJSONValueObjectAppendNumberInt(virJSONValue *object,
                                   const char *key,
                                   int number)
 {
@@ -684,7 +685,7 @@ virJSONValueObjectAppendNumberInt(virJSONValuePtr object,
 
 
 int
-virJSONValueObjectAppendNumberUint(virJSONValuePtr object,
+virJSONValueObjectAppendNumberUint(virJSONValue *object,
                                    const char *key,
                                    unsigned int number)
 {
@@ -698,7 +699,7 @@ virJSONValueObjectAppendNumberUint(virJSONValuePtr object,
 
 
 int
-virJSONValueObjectAppendNumberLong(virJSONValuePtr object,
+virJSONValueObjectAppendNumberLong(virJSONValue *object,
                                    const char *key,
                                    long long number)
 {
@@ -712,7 +713,7 @@ virJSONValueObjectAppendNumberLong(virJSONValuePtr object,
 
 
 int
-virJSONValueObjectAppendNumberUlong(virJSONValuePtr object,
+virJSONValueObjectAppendNumberUlong(virJSONValue *object,
                                     const char *key,
                                     unsigned long long number)
 {
@@ -726,7 +727,7 @@ virJSONValueObjectAppendNumberUlong(virJSONValuePtr object,
 
 
 int
-virJSONValueObjectAppendNumberDouble(virJSONValuePtr object,
+virJSONValueObjectAppendNumberDouble(virJSONValue *object,
                                      const char *key,
                                      double number)
 {
@@ -744,7 +745,7 @@ virJSONValueObjectAppendNumberDouble(virJSONValuePtr object,
 
 
 int
-virJSONValueObjectAppendBoolean(virJSONValuePtr object,
+virJSONValueObjectAppendBoolean(virJSONValue *object,
                                 const char *key,
                                 int boolean_)
 {
@@ -758,7 +759,7 @@ virJSONValueObjectAppendBoolean(virJSONValuePtr object,
 
 
 int
-virJSONValueObjectAppendNull(virJSONValuePtr object,
+virJSONValueObjectAppendNull(virJSONValue *object,
                              const char *key)
 {
     g_autoptr(virJSONValue) jvalue = virJSONValueNewNull();
@@ -771,8 +772,8 @@ virJSONValueObjectAppendNull(virJSONValuePtr object,
 
 
 int
-virJSONValueArrayAppend(virJSONValuePtr array,
-                        virJSONValuePtr *value)
+virJSONValueArrayAppend(virJSONValue *array,
+                        virJSONValue **value)
 {
     if (array->type != VIR_JSON_TYPE_ARRAY) {
         virReportError(VIR_ERR_INTERNAL_ERROR, "%s", _("expecting JSON array"));
@@ -789,7 +790,7 @@ virJSONValueArrayAppend(virJSONValuePtr array,
 
 
 int
-virJSONValueArrayAppendString(virJSONValuePtr object,
+virJSONValueArrayAppendString(virJSONValue *object,
                               const char *value)
 {
     g_autoptr(virJSONValue) jvalue = virJSONValueNewString(value);
@@ -809,8 +810,8 @@ virJSONValueArrayAppendString(virJSONValuePtr object,
  * Merges the members of @c array into @a. The values are stolen from @c.
  */
 int
-virJSONValueArrayConcat(virJSONValuePtr a,
-                        virJSONValuePtr c)
+virJSONValueArrayConcat(virJSONValue *a,
+                        virJSONValue *c)
 {
     size_t i;
 
@@ -820,7 +821,7 @@ virJSONValueArrayConcat(virJSONValuePtr a,
         return -1;
     }
 
-    a->data.array.values = g_renew(virJSONValuePtr, a->data.array.values,
+    a->data.array.values = g_renew(virJSONValue *, a->data.array.values,
                                    a->data.array.nvalues + c->data.array.nvalues);
 
     for (i = 0; i < c->data.array.nvalues; i++)
@@ -833,7 +834,7 @@ virJSONValueArrayConcat(virJSONValuePtr a,
 
 
 int
-virJSONValueObjectHasKey(virJSONValuePtr object,
+virJSONValueObjectHasKey(virJSONValue *object,
                          const char *key)
 {
     size_t i;
@@ -850,8 +851,8 @@ virJSONValueObjectHasKey(virJSONValuePtr object,
 }
 
 
-virJSONValuePtr
-virJSONValueObjectGet(virJSONValuePtr object,
+virJSONValue *
+virJSONValueObjectGet(virJSONValue *object,
                       const char *key)
 {
     size_t i;
@@ -870,12 +871,12 @@ virJSONValueObjectGet(virJSONValuePtr object,
 
 /* Return the value associated with KEY within OBJECT, but return NULL
  * if the key is missing or if value is not the correct TYPE.  */
-virJSONValuePtr
-virJSONValueObjectGetByType(virJSONValuePtr object,
+virJSONValue *
+virJSONValueObjectGetByType(virJSONValue *object,
                             const char *key,
                             virJSONType type)
 {
-    virJSONValuePtr value = virJSONValueObjectGet(object, key);
+    virJSONValue *value = virJSONValueObjectGet(object, key);
 
     if (value && value->type == type)
         return value;
@@ -885,12 +886,12 @@ virJSONValueObjectGetByType(virJSONValuePtr object,
 
 /* Steal the value associated with KEY within OBJECT, but return NULL
  * if the key is missing or if value is not the correct TYPE.  */
-static virJSONValuePtr
-virJSONValueObjectStealByType(virJSONValuePtr object,
+static virJSONValue *
+virJSONValueObjectStealByType(virJSONValue *object,
                               const char *key,
                               virJSONType type)
 {
-    virJSONValuePtr value;
+    virJSONValue *value;
 
     if (virJSONValueObjectRemoveKey(object, key, &value) <= 0)
         return NULL;
@@ -902,7 +903,7 @@ virJSONValueObjectStealByType(virJSONValuePtr object,
 
 
 int
-virJSONValueObjectKeysNumber(virJSONValuePtr object)
+virJSONValueObjectKeysNumber(virJSONValue *object)
 {
     if (object->type != VIR_JSON_TYPE_OBJECT)
         return -1;
@@ -912,7 +913,7 @@ virJSONValueObjectKeysNumber(virJSONValuePtr object)
 
 
 const char *
-virJSONValueObjectGetKey(virJSONValuePtr object,
+virJSONValueObjectGetKey(virJSONValue *object,
                          unsigned int n)
 {
     if (object->type != VIR_JSON_TYPE_OBJECT)
@@ -929,9 +930,9 @@ virJSONValueObjectGetKey(virJSONValuePtr object,
  * not NULL, the dropped value object is returned instead of freed.
  * Returns 1 on success, 0 if no key was found, and -1 on error.  */
 int
-virJSONValueObjectRemoveKey(virJSONValuePtr object,
+virJSONValueObjectRemoveKey(virJSONValue *object,
                             const char *key,
-                            virJSONValuePtr *value)
+                            virJSONValue **value)
 {
     size_t i;
 
@@ -958,8 +959,8 @@ virJSONValueObjectRemoveKey(virJSONValuePtr object,
 }
 
 
-virJSONValuePtr
-virJSONValueObjectGetValue(virJSONValuePtr object,
+virJSONValue *
+virJSONValueObjectGetValue(virJSONValue *object,
                            unsigned int n)
 {
     if (object->type != VIR_JSON_TYPE_OBJECT)
@@ -973,7 +974,7 @@ virJSONValueObjectGetValue(virJSONValuePtr object,
 
 
 bool
-virJSONValueIsObject(virJSONValuePtr object)
+virJSONValueIsObject(virJSONValue *object)
 {
     if (object)
         return object->type == VIR_JSON_TYPE_OBJECT;
@@ -983,7 +984,7 @@ virJSONValueIsObject(virJSONValuePtr object)
 
 
 bool
-virJSONValueIsArray(virJSONValuePtr array)
+virJSONValueIsArray(virJSONValue *array)
 {
     return array->type == VIR_JSON_TYPE_ARRAY;
 }
@@ -996,8 +997,8 @@ virJSONValueArraySize(const virJSONValue *array)
 }
 
 
-virJSONValuePtr
-virJSONValueArrayGet(virJSONValuePtr array,
+virJSONValue *
+virJSONValueArrayGet(virJSONValue *array,
                      unsigned int element)
 {
     if (array->type != VIR_JSON_TYPE_ARRAY)
@@ -1010,11 +1011,11 @@ virJSONValueArrayGet(virJSONValuePtr array,
 }
 
 
-virJSONValuePtr
-virJSONValueArraySteal(virJSONValuePtr array,
+virJSONValue *
+virJSONValueArraySteal(virJSONValue *array,
                        unsigned int element)
 {
-    virJSONValuePtr ret = NULL;
+    virJSONValue *ret = NULL;
 
     if (array->type != VIR_JSON_TYPE_ARRAY)
         return NULL;
@@ -1051,7 +1052,7 @@ virJSONValueArraySteal(virJSONValuePtr array,
  * The rest of the members stay in possession of the array and it's condensed.
  */
 int
-virJSONValueArrayForeachSteal(virJSONValuePtr array,
+virJSONValueArrayForeachSteal(virJSONValue *array,
                               virJSONArrayIteratorFunc cb,
                               void *opaque)
 {
@@ -1088,7 +1089,7 @@ virJSONValueArrayForeachSteal(virJSONValuePtr array,
 
 
 const char *
-virJSONValueGetString(virJSONValuePtr string)
+virJSONValueGetString(virJSONValue *string)
 {
     if (string->type != VIR_JSON_TYPE_STRING)
         return NULL;
@@ -1098,7 +1099,7 @@ virJSONValueGetString(virJSONValuePtr string)
 
 
 const char *
-virJSONValueGetNumberString(virJSONValuePtr number)
+virJSONValueGetNumberString(virJSONValue *number)
 {
     if (number->type != VIR_JSON_TYPE_NUMBER)
         return NULL;
@@ -1108,7 +1109,7 @@ virJSONValueGetNumberString(virJSONValuePtr number)
 
 
 int
-virJSONValueGetNumberInt(virJSONValuePtr number,
+virJSONValueGetNumberInt(virJSONValue *number,
                          int *value)
 {
     if (number->type != VIR_JSON_TYPE_NUMBER)
@@ -1119,7 +1120,7 @@ virJSONValueGetNumberInt(virJSONValuePtr number,
 
 
 int
-virJSONValueGetNumberUint(virJSONValuePtr number,
+virJSONValueGetNumberUint(virJSONValue *number,
                           unsigned int *value)
 {
     if (number->type != VIR_JSON_TYPE_NUMBER)
@@ -1130,7 +1131,7 @@ virJSONValueGetNumberUint(virJSONValuePtr number,
 
 
 int
-virJSONValueGetNumberLong(virJSONValuePtr number,
+virJSONValueGetNumberLong(virJSONValue *number,
                           long long *value)
 {
     if (number->type != VIR_JSON_TYPE_NUMBER)
@@ -1141,7 +1142,7 @@ virJSONValueGetNumberLong(virJSONValuePtr number,
 
 
 int
-virJSONValueGetNumberUlong(virJSONValuePtr number,
+virJSONValueGetNumberUlong(virJSONValue *number,
                            unsigned long long *value)
 {
     if (number->type != VIR_JSON_TYPE_NUMBER)
@@ -1152,7 +1153,7 @@ virJSONValueGetNumberUlong(virJSONValuePtr number,
 
 
 int
-virJSONValueGetNumberDouble(virJSONValuePtr number,
+virJSONValueGetNumberDouble(virJSONValue *number,
                             double *value)
 {
     if (number->type != VIR_JSON_TYPE_NUMBER)
@@ -1163,7 +1164,7 @@ virJSONValueGetNumberDouble(virJSONValuePtr number,
 
 
 int
-virJSONValueGetBoolean(virJSONValuePtr val,
+virJSONValueGetBoolean(virJSONValue *val,
                        bool *value)
 {
     if (val->type != VIR_JSON_TYPE_BOOLEAN)
@@ -1174,89 +1175,18 @@ virJSONValueGetBoolean(virJSONValuePtr val,
 }
 
 
-/**
- * virJSONValueGetArrayAsBitmap:
- * @val: JSON array to convert to bitmap
- * @bitmap: New bitmap is allocated filled and returned via this argument
- *
- * Attempts a conversion of a JSON array to a bitmap. The members of the array
- * must be non-negative integers for the conversion to succeed. This function
- * does not report libvirt errors so that it can be used to probe that the
- * array can be represented as a bitmap.
- *
- * Returns 0 on success and fills @bitmap; -1 on error and  @bitmap is set to
- * NULL.
- */
-int
-virJSONValueGetArrayAsBitmap(const virJSONValue *val,
-                             virBitmapPtr *bitmap)
-{
-    virJSONValuePtr elem;
-    size_t i;
-    g_autofree unsigned long long *elems = NULL;
-    unsigned long long maxelem = 0;
-
-    *bitmap = NULL;
-
-    if (val->type != VIR_JSON_TYPE_ARRAY)
-        return -1;
-
-    elems = g_new0(unsigned long long, val->data.array.nvalues);
-
-    /* first pass converts array members to numbers and finds the maximum */
-    for (i = 0; i < val->data.array.nvalues; i++) {
-        elem = val->data.array.values[i];
-
-        if (elem->type != VIR_JSON_TYPE_NUMBER ||
-            virStrToLong_ullp(elem->data.number, NULL, 10, &elems[i]) < 0)
-            return -1;
-
-        if (elems[i] > maxelem)
-            maxelem = elems[i];
-    }
-
-    *bitmap = virBitmapNew(maxelem + 1);
-
-    /* second pass sets the correct bits in the map */
-    for (i = 0; i < val->data.array.nvalues; i++)
-        ignore_value(virBitmapSetBit(*bitmap, elems[i]));
-
-    return 0;
-}
-
-
-virJSONValuePtr
-virJSONValueNewArrayFromBitmap(virBitmapPtr bitmap)
-{
-    g_autoptr(virJSONValue) ret = virJSONValueNewArray();
-    ssize_t pos = -1;
-
-    if (!bitmap)
-        return g_steal_pointer(&ret);
-
-    while ((pos = virBitmapNextSetBit(bitmap, pos)) > -1) {
-        g_autoptr(virJSONValue) newelem = virJSONValueNewNumberLong(pos);
-
-        if (virJSONValueArrayAppend(ret, &newelem) < 0)
-            return NULL;
-    }
-
-    return g_steal_pointer(&ret);
-}
-
-
 bool
-virJSONValueIsNull(virJSONValuePtr val)
+virJSONValueIsNull(virJSONValue *val)
 {
     return val->type == VIR_JSON_TYPE_NULL;
 }
 
 
 const char *
-virJSONValueObjectGetString(virJSONValuePtr object,
+virJSONValueObjectGetString(virJSONValue *object,
                             const char *key)
 {
-    virJSONValuePtr val = virJSONValueObjectGet(object, key);
+    virJSONValue *val = virJSONValueObjectGet(object, key);
 
     if (!val)
         return NULL;
@@ -1275,10 +1205,10 @@ virJSONValueObjectGetString(virJSONValuePtr object,
  * is not present or is not a string or number NULL is returned.
  */
 const char *
-virJSONValueObjectGetStringOrNumber(virJSONValuePtr object,
+virJSONValueObjectGetStringOrNumber(virJSONValue *object,
                                     const char *key)
 {
-    virJSONValuePtr val = virJSONValueObjectGet(object, key);
+    virJSONValue *val = virJSONValueObjectGet(object, key);
 
     if (!val)
         return NULL;
@@ -1293,11 +1223,11 @@ virJSONValueObjectGetStringOrNumber(virJSONValuePtr object,
 
 
 int
-virJSONValueObjectGetNumberInt(virJSONValuePtr object,
+virJSONValueObjectGetNumberInt(virJSONValue *object,
                                const char *key,
                                int *value)
 {
-    virJSONValuePtr val = virJSONValueObjectGet(object, key);
+    virJSONValue *val = virJSONValueObjectGet(object, key);
 
     if (!val)
         return -1;
@@ -1307,11 +1237,11 @@ virJSONValueObjectGetNumberInt(virJSONValuePtr object,
 
 
 int
-virJSONValueObjectGetNumberUint(virJSONValuePtr object,
+virJSONValueObjectGetNumberUint(virJSONValue *object,
                                 const char *key,
                                 unsigned int *value)
 {
-    virJSONValuePtr val = virJSONValueObjectGet(object, key);
+    virJSONValue *val = virJSONValueObjectGet(object, key);
 
     if (!val)
         return -1;
@@ -1321,11 +1251,11 @@ virJSONValueObjectGetNumberUint(virJSONValuePtr object,
 
 
 int
-virJSONValueObjectGetNumberLong(virJSONValuePtr object,
+virJSONValueObjectGetNumberLong(virJSONValue *object,
                                 const char *key,
                                 long long *value)
 {
-    virJSONValuePtr val = virJSONValueObjectGet(object, key);
+    virJSONValue *val = virJSONValueObjectGet(object, key);
 
     if (!val)
         return -1;
@@ -1335,11 +1265,11 @@ virJSONValueObjectGetNumberLong(virJSONValuePtr object,
 
 
 int
-virJSONValueObjectGetNumberUlong(virJSONValuePtr object,
+virJSONValueObjectGetNumberUlong(virJSONValue *object,
                                  const char *key,
                                  unsigned long long *value)
 {
-    virJSONValuePtr val = virJSONValueObjectGet(object, key);
+    virJSONValue *val = virJSONValueObjectGet(object, key);
 
     if (!val)
         return -1;
@@ -1349,11 +1279,11 @@ virJSONValueObjectGetNumberUlong(virJSONValuePtr object,
 
 
 int
-virJSONValueObjectGetNumberDouble(virJSONValuePtr object,
+virJSONValueObjectGetNumberDouble(virJSONValue *object,
                                   const char *key,
                                   double *value)
 {
-    virJSONValuePtr val = virJSONValueObjectGet(object, key);
+    virJSONValue *val = virJSONValueObjectGet(object, key);
 
     if (!val)
         return -1;
@@ -1363,11 +1293,11 @@ virJSONValueObjectGetNumberDouble(virJSONValuePtr object,
 
 
 int
-virJSONValueObjectGetBoolean(virJSONValuePtr object,
+virJSONValueObjectGetBoolean(virJSONValue *object,
                              const char *key,
                              bool *value)
 {
-    virJSONValuePtr val = virJSONValueObjectGet(object, key);
+    virJSONValue *val = virJSONValueObjectGet(object, key);
 
     if (!val)
         return -1;
@@ -1376,29 +1306,29 @@ virJSONValueObjectGetBoolean(virJSONValuePtr object,
 }
 
 
-virJSONValuePtr
-virJSONValueObjectGetObject(virJSONValuePtr object, const char *key)
+virJSONValue *
+virJSONValueObjectGetObject(virJSONValue *object, const char *key)
 {
     return virJSONValueObjectGetByType(object, key, VIR_JSON_TYPE_OBJECT);
 }
 
 
-virJSONValuePtr
-virJSONValueObjectGetArray(virJSONValuePtr object, const char *key)
+virJSONValue *
+virJSONValueObjectGetArray(virJSONValue *object, const char *key)
 {
     return virJSONValueObjectGetByType(object, key, VIR_JSON_TYPE_ARRAY);
 }
 
 
-virJSONValuePtr
-virJSONValueObjectStealArray(virJSONValuePtr object, const char *key)
+virJSONValue *
+virJSONValueObjectStealArray(virJSONValue *object, const char *key)
 {
     return virJSONValueObjectStealByType(object, key, VIR_JSON_TYPE_ARRAY);
 }
 
 
-virJSONValuePtr
-virJSONValueObjectStealObject(virJSONValuePtr object,
+virJSONValue *
+virJSONValueObjectStealObject(virJSONValue *object,
                               const char *key)
 {
     return virJSONValueObjectStealByType(object, key, VIR_JSON_TYPE_OBJECT);
@@ -1406,10 +1336,10 @@ virJSONValueObjectStealObject(virJSONValuePtr object,
 
 
 int
-virJSONValueObjectIsNull(virJSONValuePtr object,
+virJSONValueObjectIsNull(virJSONValue *object,
                          const char *key)
 {
-    virJSONValuePtr val = virJSONValueObjectGet(object, key);
+    virJSONValue *val = virJSONValueObjectGet(object, key);
 
     if (!val)
         return -1;
@@ -1418,10 +1348,10 @@ virJSONValueObjectIsNull(virJSONValuePtr object,
 }
 
 char **
-virJSONValueObjectGetStringArray(virJSONValuePtr object, const char *key)
+virJSONValueObjectGetStringArray(virJSONValue *object, const char *key)
 {
     g_auto(GStrv) ret = NULL;
-    virJSONValuePtr data;
+    virJSONValue *data;
     size_t n;
     size_t i;
 
@@ -1436,7 +1366,7 @@ virJSONValueObjectGetStringArray(virJSONValuePtr object, const char *key)
     n = virJSONValueArraySize(data);
     ret = g_new0(char *, n + 1);
     for (i = 0; i < n; i++) {
-        virJSONValuePtr child = virJSONValueArrayGet(data, i);
+        virJSONValue *child = virJSONValueArrayGet(data, i);
         const char *tmp;
 
         if (!child) {
@@ -1472,7 +1402,7 @@ virJSONValueObjectGetStringArray(virJSONValuePtr object, const char *key)
  * during iteration and -1 on generic errors.
  */
 int
-virJSONValueObjectForeachKeyValue(virJSONValuePtr object,
+virJSONValueObjectForeachKeyValue(virJSONValue *object,
                                   virJSONValueObjectIteratorFunc cb,
                                   void *opaque)
 {
@@ -1482,7 +1412,7 @@ virJSONValueObjectForeachKeyValue(virJSONValuePtr object,
         return -1;
 
     for (i = 0; i < object->data.object.npairs; i++) {
-        virJSONObjectPairPtr elem = object->data.object.pairs + i;
+        virJSONObjectPair *elem = object->data.object.pairs + i;
 
         if (cb(elem->key, elem->value, opaque) < 0)
             return -2;
@@ -1492,11 +1422,11 @@ virJSONValueObjectForeachKeyValue(virJSONValuePtr object,
 }
 
 
-virJSONValuePtr
+virJSONValue *
 virJSONValueCopy(const virJSONValue *in)
 {
     size_t i;
-    virJSONValuePtr out = NULL;
+    virJSONValue *out = NULL;
 
     if (!in)
         return NULL;
@@ -1516,7 +1446,7 @@ virJSONValueCopy(const virJSONValue *in)
     case VIR_JSON_TYPE_ARRAY:
         out = virJSONValueNewArray();
 
-        out->data.array.values = g_new0(virJSONValuePtr, in->data.array.nvalues);
+        out->data.array.values = g_new0(virJSONValue *, in->data.array.nvalues);
         out->data.array.nvalues = in->data.array.nvalues;
 
         for (i = 0; i < in->data.array.nvalues; i++) {
@@ -1545,13 +1475,13 @@ virJSONValueCopy(const virJSONValue *in)
 
 #if WITH_YAJL
 static int
-virJSONParserInsertValue(virJSONParserPtr parser,
-                         virJSONValuePtr *value)
+virJSONParserInsertValue(virJSONParser *parser,
+                         virJSONValue **value)
 {
     if (!parser->head) {
         parser->head = g_steal_pointer(value);
     } else {
-        virJSONParserStatePtr state;
+        virJSONParserState *state;
         if (!parser->nstate) {
             VIR_DEBUG("got a value to insert without a container");
             return -1;
@@ -1598,7 +1528,7 @@ virJSONParserInsertValue(virJSONParserPtr parser,
 static int
 virJSONParserHandleNull(void *ctx)
 {
-    virJSONParserPtr parser = ctx;
+    virJSONParser *parser = ctx;
     g_autoptr(virJSONValue) value = virJSONValueNewNull();
 
     VIR_DEBUG("parser=%p", parser);
@@ -1614,7 +1544,7 @@ static int
 virJSONParserHandleBoolean(void *ctx,
                            int boolean_)
 {
-    virJSONParserPtr parser = ctx;
+    virJSONParser *parser = ctx;
     g_autoptr(virJSONValue) value = virJSONValueNewBoolean(boolean_);
 
     VIR_DEBUG("parser=%p boolean=%d", parser, boolean_);
@@ -1631,7 +1561,7 @@ virJSONParserHandleNumber(void *ctx,
                           const char *s,
                           size_t l)
 {
-    virJSONParserPtr parser = ctx;
+    virJSONParser *parser = ctx;
     g_autoptr(virJSONValue) value = virJSONValueNewNumber(g_strndup(s, l));
 
     VIR_DEBUG("parser=%p str=%s", parser, value->data.number);
@@ -1648,7 +1578,7 @@ virJSONParserHandleString(void *ctx,
                           const unsigned char *stringVal,
                           size_t stringLen)
 {
-    virJSONParserPtr parser = ctx;
+    virJSONParser *parser = ctx;
     g_autoptr(virJSONValue) value = virJSONValueNewStringLen((const char *)stringVal,
                                                              stringLen);
 
@@ -1666,8 +1596,8 @@ virJSONParserHandleMapKey(void *ctx,
                           const unsigned char *stringVal,
                           size_t stringLen)
 {
-    virJSONParserPtr parser = ctx;
-    virJSONParserStatePtr state;
+    virJSONParser *parser = ctx;
+    virJSONParserState *state;
 
     VIR_DEBUG("parser=%p key=%p", parser, (const char *)stringVal);
 
@@ -1685,9 +1615,9 @@ virJSONParserHandleMapKey(void *ctx,
 static int
 virJSONParserHandleStartMap(void *ctx)
 {
-    virJSONParserPtr parser = ctx;
+    virJSONParser *parser = ctx;
     g_autoptr(virJSONValue) value = virJSONValueNewObject();
-    virJSONValuePtr tmp = value;
+    virJSONValue *tmp = value;
 
     VIR_DEBUG("parser=%p", parser);
 
@@ -1707,8 +1637,8 @@ virJSONParserHandleStartMap(void *ctx)
 static int
 virJSONParserHandleEndMap(void *ctx)
 {
-    virJSONParserPtr parser = ctx;
-    virJSONParserStatePtr state;
+    virJSONParser *parser = ctx;
+    virJSONParserState *state;
 
     VIR_DEBUG("parser=%p", parser);
 
@@ -1730,9 +1660,9 @@ virJSONParserHandleEndMap(void *ctx)
 static int
 virJSONParserHandleStartArray(void *ctx)
 {
-    virJSONParserPtr parser = ctx;
+    virJSONParser *parser = ctx;
     g_autoptr(virJSONValue) value = virJSONValueNewArray();
-    virJSONValuePtr tmp = value;
+    virJSONValue *tmp = value;
 
     VIR_DEBUG("parser=%p", parser);
 
@@ -1752,8 +1682,8 @@ virJSONParserHandleStartArray(void *ctx)
 static int
 virJSONParserHandleEndArray(void *ctx)
 {
-    virJSONParserPtr parser = ctx;
-    virJSONParserStatePtr state;
+    virJSONParser *parser = ctx;
+    virJSONParserState *state;
 
     VIR_DEBUG("parser=%p", parser);
 
@@ -1788,12 +1718,12 @@ static const yajl_callbacks parserCallbacks = {
 
 
 /* XXX add an incremental streaming parser - yajl trivially supports it */
-virJSONValuePtr
+virJSONValue *
 virJSONValueFromString(const char *jsonstring)
 {
     yajl_handle hand;
     virJSONParser parser = { NULL, NULL, 0, 0 };
-    virJSONValuePtr ret = NULL;
+    virJSONValue *ret = NULL;
     int rc;
     size_t len = strlen(jsonstring);
 
@@ -1848,7 +1778,7 @@ virJSONValueFromString(const char *jsonstring)
 
 
 static int
-virJSONValueToStringOne(virJSONValuePtr object,
+virJSONValueToStringOne(virJSONValue *object,
                         yajl_gen g)
 {
     size_t i;
@@ -1913,8 +1843,8 @@ virJSONValueToStringOne(virJSONValuePtr object,
 
 
 int
-virJSONValueToBuffer(virJSONValuePtr object,
-                     virBufferPtr buf,
+virJSONValueToBuffer(virJSONValue *object,
+                     virBuffer *buf,
                      bool pretty)
 {
     yajl_gen g;
@@ -1957,7 +1887,7 @@ virJSONValueToBuffer(virJSONValuePtr object,
 
 
 #else
-virJSONValuePtr
+virJSONValue *
 virJSONValueFromString(const char *jsonstring G_GNUC_UNUSED)
 {
     virReportError(VIR_ERR_INTERNAL_ERROR, "%s",
@@ -1967,8 +1897,8 @@ virJSONValueFromString(const char *jsonstring G_GNUC_UNUSED)
 
 
 int
-virJSONValueToBuffer(virJSONValuePtr object G_GNUC_UNUSED,
-                     virBufferPtr buf G_GNUC_UNUSED,
+virJSONValueToBuffer(virJSONValue *object G_GNUC_UNUSED,
+                     virBuffer *buf G_GNUC_UNUSED,
                      bool pretty G_GNUC_UNUSED)
 {
     virReportError(VIR_ERR_INTERNAL_ERROR, "%s",
@@ -1979,7 +1909,7 @@ virJSONValueToBuffer(virJSONValuePtr object G_GNUC_UNUSED,
 
 
 char *
-virJSONValueToString(virJSONValuePtr object,
+virJSONValueToString(virJSONValue *object,
                      bool pretty)
 {
     g_auto(virBuffer) buf = VIR_BUFFER_INITIALIZER;
@@ -2016,20 +1946,19 @@ virJSONStringReformat(const char *jsonstr,
 }
 
 
-static virJSONValuePtr
-virJSONValueObjectDeflattenKeys(virJSONValuePtr json);
+static virJSONValue *
+virJSONValueObjectDeflattenKeys(virJSONValue *json);
 
 
 static int
 virJSONValueObjectDeflattenWorker(const char *key,
-                                  virJSONValuePtr value,
+                                  virJSONValue *value,
                                   void *opaque)
 {
-    virJSONValuePtr retobj = opaque;
+    virJSONValue *retobj = opaque;
     g_autoptr(virJSONValue) newval = NULL;
-    virJSONValuePtr existobj;
+    virJSONValue *existobj;
     g_auto(GStrv) tokens = NULL;
-    size_t ntokens = 0;
 
     /* non-nested keys only need to be copied */
     if (!strchr(key, '.')) {
@@ -2054,17 +1983,17 @@ virJSONValueObjectDeflattenWorker(const char *key,
         return 0;
     }
 
-    if (!(tokens = virStringSplitCount(key, ".", 2, &ntokens)))
+    if (!(tokens = g_strsplit(key, ".", 2)))
         return -1;
 
-    if (ntokens != 2) {
+    if (!tokens[0] || !tokens[1]) {
         virReportError(VIR_ERR_INVALID_ARG,
                        _("invalid nested value key '%s'"), key);
         return -1;
     }
 
     if (!(existobj = virJSONValueObjectGet(retobj, tokens[0]))) {
-        virJSONValuePtr newobj = virJSONValueNewObject();
+        virJSONValue *newobj = virJSONValueNewObject();
         existobj = newobj;
 
         if (virJSONValueObjectAppend(retobj, tokens[0], &newobj) < 0)
@@ -2083,8 +2012,8 @@ virJSONValueObjectDeflattenWorker(const char *key,
 }
 
 
-static virJSONValuePtr
-virJSONValueObjectDeflattenKeys(virJSONValuePtr json)
+static virJSONValue *
+virJSONValueObjectDeflattenKeys(virJSONValue *json)
 {
     g_autoptr(virJSONValue) deflattened = virJSONValueNewObject();
 
@@ -2104,10 +2033,10 @@ virJSONValueObjectDeflattenKeys(virJSONValuePtr json)
  * keys starting from 0.
  */
 static void
-virJSONValueObjectDeflattenArrays(virJSONValuePtr json)
+virJSONValueObjectDeflattenArrays(virJSONValue *json)
 {
-    g_autofree virJSONValuePtr *arraymembers = NULL;
-    virJSONObjectPtr obj;
+    g_autofree virJSONValue **arraymembers = NULL;
+    virJSONObject *obj;
     size_t i;
 
     if (!json ||
@@ -2116,13 +2045,13 @@ virJSONValueObjectDeflattenArrays(virJSONValuePtr json)
 
     obj = &json->data.object;
 
-    arraymembers = g_new0(virJSONValuePtr, obj->npairs);
+    arraymembers = g_new0(virJSONValue *, obj->npairs);
 
     for (i = 0; i < obj->npairs; i++)
         virJSONValueObjectDeflattenArrays(obj->pairs[i].value);
 
     for (i = 0; i < obj->npairs; i++) {
-        virJSONObjectPairPtr pair = obj->pairs + i;
+        virJSONObjectPair *pair = obj->pairs + i;
         unsigned int keynum;
 
         if (virStrToLong_uip(pair->key, NULL, 10, &keynum) < 0)
@@ -2161,10 +2090,10 @@ virJSONValueObjectDeflattenArrays(virJSONValuePtr json)
  * hierarchy so that the parsers can be kept simple and we still can use the
  * weird syntax some users might use.
  */
-virJSONValuePtr
-virJSONValueObjectDeflatten(virJSONValuePtr json)
+virJSONValue *
+virJSONValueObjectDeflatten(virJSONValue *json)
 {
-    virJSONValuePtr deflattened;
+    virJSONValue *deflattened;
 
     if (!(deflattened = virJSONValueObjectDeflattenKeys(json)))
         return NULL;
