@@ -42,11 +42,10 @@
 # endif
 
 typedef struct _virNWFilterInst virNWFilterInst;
-typedef virNWFilterInst *virNWFilterInstPtr;
 struct _virNWFilterInst {
-    virNWFilterDefPtr *filters;
+    virNWFilterDef **filters;
     size_t nfilters;
-    virNWFilterRuleInstPtr *rules;
+    virNWFilterRuleInst **rules;
     size_t nrules;
 };
 
@@ -58,90 +57,90 @@ struct _virNWFilterInst {
 
 static const char *commonRules[] = {
     /* Dropping ebtables rules */
-    "ebtables --concurrent -t nat -D PREROUTING -i vnet0 -j libvirt-J-vnet0\n"
-    "ebtables --concurrent -t nat -D POSTROUTING -o vnet0 -j libvirt-P-vnet0\n"
-    "ebtables --concurrent -t nat -L libvirt-J-vnet0\n"
-    "ebtables --concurrent -t nat -L libvirt-P-vnet0\n"
-    "ebtables --concurrent -t nat -F libvirt-J-vnet0\n"
-    "ebtables --concurrent -t nat -X libvirt-J-vnet0\n"
-    "ebtables --concurrent -t nat -F libvirt-P-vnet0\n"
-    "ebtables --concurrent -t nat -X libvirt-P-vnet0\n",
+    "ebtables \\\n--concurrent \\\n-t nat \\\n-D PREROUTING \\\n-i vnet0 \\\n-j libvirt-J-vnet0\n"
+    "ebtables \\\n--concurrent \\\n-t nat \\\n-D POSTROUTING \\\n-o vnet0 \\\n-j libvirt-P-vnet0\n"
+    "ebtables \\\n--concurrent \\\n-t nat \\\n-L libvirt-J-vnet0\n"
+    "ebtables \\\n--concurrent \\\n-t nat \\\n-L libvirt-P-vnet0\n"
+    "ebtables \\\n--concurrent \\\n-t nat \\\n-F libvirt-J-vnet0\n"
+    "ebtables \\\n--concurrent \\\n-t nat \\\n-X libvirt-J-vnet0\n"
+    "ebtables \\\n--concurrent \\\n-t nat \\\n-F libvirt-P-vnet0\n"
+    "ebtables \\\n--concurrent \\\n-t nat \\\n-X libvirt-P-vnet0\n",
 
     /* Creating ebtables chains */
-    "ebtables --concurrent -t nat -N libvirt-J-vnet0\n"
-    "ebtables --concurrent -t nat -N libvirt-P-vnet0\n",
+    "ebtables \\\n--concurrent \\\n-t nat \\\n-N libvirt-J-vnet0\n"
+    "ebtables \\\n--concurrent \\\n-t nat \\\n-N libvirt-P-vnet0\n",
 
     /* Dropping iptables rules */
-    "iptables -w -D libvirt-out -m physdev --physdev-is-bridged --physdev-out vnet0 -g FP-vnet0\n"
-    "iptables -w -D libvirt-out -m physdev --physdev-out vnet0 -g FP-vnet0\n"
-    "iptables -w -D libvirt-in -m physdev --physdev-in vnet0 -g FJ-vnet0\n"
-    "iptables -w -D libvirt-host-in -m physdev --physdev-in vnet0 -g HJ-vnet0\n"
-    "iptables -w -F FP-vnet0\n"
-    "iptables -w -X FP-vnet0\n"
-    "iptables -w -F FJ-vnet0\n"
-    "iptables -w -X FJ-vnet0\n"
-    "iptables -w -F HJ-vnet0\n"
-    "iptables -w -X HJ-vnet0\n",
+    "iptables \\\n-w \\\n-D libvirt-out \\\n-m physdev \\\n--physdev-is-bridged \\\n--physdev-out vnet0 \\\n-g FP-vnet0\n"
+    "iptables \\\n-w \\\n-D libvirt-out \\\n-m physdev \\\n--physdev-out vnet0 \\\n-g FP-vnet0\n"
+    "iptables \\\n-w \\\n-D libvirt-in \\\n-m physdev \\\n--physdev-in vnet0 \\\n-g FJ-vnet0\n"
+    "iptables \\\n-w \\\n-D libvirt-host-in \\\n-m physdev \\\n--physdev-in vnet0 \\\n-g HJ-vnet0\n"
+    "iptables \\\n-w \\\n-F FP-vnet0\n"
+    "iptables \\\n-w \\\n-X FP-vnet0\n"
+    "iptables \\\n-w \\\n-F FJ-vnet0\n"
+    "iptables \\\n-w \\\n-X FJ-vnet0\n"
+    "iptables \\\n-w \\\n-F HJ-vnet0\n"
+    "iptables \\\n-w \\\n-X HJ-vnet0\n",
 
     /* Creating iptables chains */
-    "iptables -w -N libvirt-in\n"
-    "iptables -w -N libvirt-out\n"
-    "iptables -w -N libvirt-in-post\n"
-    "iptables -w -N libvirt-host-in\n"
-    "iptables -w -D FORWARD -j libvirt-in\n"
-    "iptables -w -D FORWARD -j libvirt-out\n"
-    "iptables -w -D FORWARD -j libvirt-in-post\n"
-    "iptables -w -D INPUT -j libvirt-host-in\n"
-    "iptables -w -I FORWARD 1 -j libvirt-in\n"
-    "iptables -w -I FORWARD 2 -j libvirt-out\n"
-    "iptables -w -I FORWARD 3 -j libvirt-in-post\n"
-    "iptables -w -I INPUT 1 -j libvirt-host-in\n"
-    "iptables -w -N FP-vnet0\n"
-    "iptables -w -N FJ-vnet0\n"
-    "iptables -w -N HJ-vnet0\n"
-    "iptables -w -A libvirt-out -m physdev --physdev-is-bridged --physdev-out vnet0 -g FP-vnet0\n"
-    "iptables -w -A libvirt-in -m physdev --physdev-in vnet0 -g FJ-vnet0\n"
-    "iptables -w -A libvirt-host-in -m physdev --physdev-in vnet0 -g HJ-vnet0\n"
-    "iptables -w -D libvirt-in-post -m physdev --physdev-in vnet0 -j ACCEPT\n"
-    "iptables -w -A libvirt-in-post -m physdev --physdev-in vnet0 -j ACCEPT\n",
+    "iptables \\\n-w \\\n-N libvirt-in\n"
+    "iptables \\\n-w \\\n-N libvirt-out\n"
+    "iptables \\\n-w \\\n-N libvirt-in-post\n"
+    "iptables \\\n-w \\\n-N libvirt-host-in\n"
+    "iptables \\\n-w \\\n-D FORWARD \\\n-j libvirt-in\n"
+    "iptables \\\n-w \\\n-D FORWARD \\\n-j libvirt-out\n"
+    "iptables \\\n-w \\\n-D FORWARD \\\n-j libvirt-in-post\n"
+    "iptables \\\n-w \\\n-D INPUT \\\n-j libvirt-host-in\n"
+    "iptables \\\n-w \\\n-I FORWARD 1 \\\n-j libvirt-in\n"
+    "iptables \\\n-w \\\n-I FORWARD 2 \\\n-j libvirt-out\n"
+    "iptables \\\n-w \\\n-I FORWARD 3 \\\n-j libvirt-in-post\n"
+    "iptables \\\n-w \\\n-I INPUT 1 \\\n-j libvirt-host-in\n"
+    "iptables \\\n-w \\\n-N FP-vnet0\n"
+    "iptables \\\n-w \\\n-N FJ-vnet0\n"
+    "iptables \\\n-w \\\n-N HJ-vnet0\n"
+    "iptables \\\n-w \\\n-A libvirt-out \\\n-m physdev \\\n--physdev-is-bridged \\\n--physdev-out vnet0 \\\n-g FP-vnet0\n"
+    "iptables \\\n-w \\\n-A libvirt-in \\\n-m physdev \\\n--physdev-in vnet0 \\\n-g FJ-vnet0\n"
+    "iptables \\\n-w \\\n-A libvirt-host-in \\\n-m physdev \\\n--physdev-in vnet0 \\\n-g HJ-vnet0\n"
+    "iptables \\\n-w \\\n-D libvirt-in-post \\\n-m physdev \\\n--physdev-in vnet0 \\\n-j ACCEPT\n"
+    "iptables \\\n-w \\\n-A libvirt-in-post \\\n-m physdev \\\n--physdev-in vnet0 \\\n-j ACCEPT\n",
 
     /* Dropping ip6tables rules */
-    "ip6tables -w -D libvirt-out -m physdev --physdev-is-bridged --physdev-out vnet0 -g FP-vnet0\n"
-    "ip6tables -w -D libvirt-out -m physdev --physdev-out vnet0 -g FP-vnet0\n"
-    "ip6tables -w -D libvirt-in -m physdev --physdev-in vnet0 -g FJ-vnet0\n"
-    "ip6tables -w -D libvirt-host-in -m physdev --physdev-in vnet0 -g HJ-vnet0\n"
-    "ip6tables -w -F FP-vnet0\n"
-    "ip6tables -w -X FP-vnet0\n"
-    "ip6tables -w -F FJ-vnet0\n"
-    "ip6tables -w -X FJ-vnet0\n"
-    "ip6tables -w -F HJ-vnet0\n"
-    "ip6tables -w -X HJ-vnet0\n",
+    "ip6tables \\\n-w \\\n-D libvirt-out \\\n-m physdev \\\n--physdev-is-bridged \\\n--physdev-out vnet0 \\\n-g FP-vnet0\n"
+    "ip6tables \\\n-w \\\n-D libvirt-out \\\n-m physdev \\\n--physdev-out vnet0 \\\n-g FP-vnet0\n"
+    "ip6tables \\\n-w \\\n-D libvirt-in \\\n-m physdev \\\n--physdev-in vnet0 \\\n-g FJ-vnet0\n"
+    "ip6tables \\\n-w \\\n-D libvirt-host-in \\\n-m physdev \\\n--physdev-in vnet0 \\\n-g HJ-vnet0\n"
+    "ip6tables \\\n-w \\\n-F FP-vnet0\n"
+    "ip6tables \\\n-w \\\n-X FP-vnet0\n"
+    "ip6tables \\\n-w \\\n-F FJ-vnet0\n"
+    "ip6tables \\\n-w \\\n-X FJ-vnet0\n"
+    "ip6tables \\\n-w \\\n-F HJ-vnet0\n"
+    "ip6tables \\\n-w \\\n-X HJ-vnet0\n",
 
     /* Creating ip6tables chains */
-    "ip6tables -w -N libvirt-in\n"
-    "ip6tables -w -N libvirt-out\n"
-    "ip6tables -w -N libvirt-in-post\n"
-    "ip6tables -w -N libvirt-host-in\n"
-    "ip6tables -w -D FORWARD -j libvirt-in\n"
-    "ip6tables -w -D FORWARD -j libvirt-out\n"
-    "ip6tables -w -D FORWARD -j libvirt-in-post\n"
-    "ip6tables -w -D INPUT -j libvirt-host-in\n"
-    "ip6tables -w -I FORWARD 1 -j libvirt-in\n"
-    "ip6tables -w -I FORWARD 2 -j libvirt-out\n"
-    "ip6tables -w -I FORWARD 3 -j libvirt-in-post\n"
-    "ip6tables -w -I INPUT 1 -j libvirt-host-in\n"
-    "ip6tables -w -N FP-vnet0\n"
-    "ip6tables -w -N FJ-vnet0\n"
-    "ip6tables -w -N HJ-vnet0\n"
-    "ip6tables -w -A libvirt-out -m physdev --physdev-is-bridged --physdev-out vnet0 -g FP-vnet0\n"
-    "ip6tables -w -A libvirt-in -m physdev --physdev-in vnet0 -g FJ-vnet0\n"
-    "ip6tables -w -A libvirt-host-in -m physdev --physdev-in vnet0 -g HJ-vnet0\n"
-    "ip6tables -w -D libvirt-in-post -m physdev --physdev-in vnet0 -j ACCEPT\n"
-    "ip6tables -w -A libvirt-in-post -m physdev --physdev-in vnet0 -j ACCEPT\n",
+    "ip6tables \\\n-w \\\n-N libvirt-in\n"
+    "ip6tables \\\n-w \\\n-N libvirt-out\n"
+    "ip6tables \\\n-w \\\n-N libvirt-in-post\n"
+    "ip6tables \\\n-w \\\n-N libvirt-host-in\n"
+    "ip6tables \\\n-w \\\n-D FORWARD \\\n-j libvirt-in\n"
+    "ip6tables \\\n-w \\\n-D FORWARD \\\n-j libvirt-out\n"
+    "ip6tables \\\n-w \\\n-D FORWARD \\\n-j libvirt-in-post\n"
+    "ip6tables \\\n-w \\\n-D INPUT \\\n-j libvirt-host-in\n"
+    "ip6tables \\\n-w \\\n-I FORWARD 1 \\\n-j libvirt-in\n"
+    "ip6tables \\\n-w \\\n-I FORWARD 2 \\\n-j libvirt-out\n"
+    "ip6tables \\\n-w \\\n-I FORWARD 3 \\\n-j libvirt-in-post\n"
+    "ip6tables \\\n-w \\\n-I INPUT 1 \\\n-j libvirt-host-in\n"
+    "ip6tables \\\n-w \\\n-N FP-vnet0\n"
+    "ip6tables \\\n-w \\\n-N FJ-vnet0\n"
+    "ip6tables \\\n-w \\\n-N HJ-vnet0\n"
+    "ip6tables \\\n-w \\\n-A libvirt-out \\\n-m physdev \\\n--physdev-is-bridged \\\n--physdev-out vnet0 \\\n-g FP-vnet0\n"
+    "ip6tables \\\n-w \\\n-A libvirt-in \\\n-m physdev \\\n--physdev-in vnet0 \\\n-g FJ-vnet0\n"
+    "ip6tables \\\n-w \\\n-A libvirt-host-in \\\n-m physdev \\\n--physdev-in vnet0 \\\n-g HJ-vnet0\n"
+    "ip6tables \\\n-w \\\n-D libvirt-in-post \\\n-m physdev \\\n--physdev-in vnet0 \\\n-j ACCEPT\n"
+    "ip6tables \\\n-w \\\n-A libvirt-in-post \\\n-m physdev \\\n--physdev-in vnet0 \\\n-j ACCEPT\n",
 
     /* Inserting ebtables rules */
-    "ebtables --concurrent -t nat -A PREROUTING -i vnet0 -j libvirt-J-vnet0\n"
-    "ebtables --concurrent -t nat -A POSTROUTING -o vnet0 -j libvirt-P-vnet0\n",
+    "ebtables \\\n--concurrent \\\n-t nat \\\n-A PREROUTING \\\n-i vnet0 \\\n-j libvirt-J-vnet0\n"
+    "ebtables \\\n--concurrent \\\n-t nat \\\n-A POSTROUTING \\\n-o vnet0 \\\n-j libvirt-P-vnet0\n",
 };
 
 
@@ -168,7 +167,7 @@ virNWFilterCreateVarsFrom(GHashTable *vars1,
 
 
 static void
-virNWFilterRuleInstFree(virNWFilterRuleInstPtr inst)
+virNWFilterRuleInstFree(virNWFilterRuleInst *inst)
 {
     if (!inst)
         return;
@@ -179,7 +178,7 @@ virNWFilterRuleInstFree(virNWFilterRuleInstPtr inst)
 
 
 static void
-virNWFilterInstReset(virNWFilterInstPtr inst)
+virNWFilterInstReset(virNWFilterInst *inst)
 {
     size_t i;
 
@@ -198,15 +197,15 @@ virNWFilterInstReset(virNWFilterInstPtr inst)
 static int
 virNWFilterDefToInst(const char *xml,
                      GHashTable *vars,
-                     virNWFilterInstPtr inst);
+                     virNWFilterInst *inst);
 
 static int
-virNWFilterRuleDefToRuleInst(virNWFilterDefPtr def,
-                             virNWFilterRuleDefPtr rule,
+virNWFilterRuleDefToRuleInst(virNWFilterDef *def,
+                             virNWFilterRuleDef *rule,
                              GHashTable *vars,
-                             virNWFilterInstPtr inst)
+                             virNWFilterInst *inst)
 {
-    virNWFilterRuleInstPtr ruleinst;
+    virNWFilterRuleInst *ruleinst;
     int ret = -1;
 
     ruleinst = g_new0(virNWFilterRuleInst, 1);
@@ -234,9 +233,9 @@ virNWFilterRuleDefToRuleInst(virNWFilterDefPtr def,
 
 
 static int
-virNWFilterIncludeDefToRuleInst(virNWFilterIncludeDefPtr inc,
+virNWFilterIncludeDefToRuleInst(virNWFilterIncludeDef *inc,
                                 GHashTable *vars,
-                                virNWFilterInstPtr inst)
+                                virNWFilterInst *inst)
 {
     GHashTable *tmpvars = NULL;
     int ret = -1;
@@ -267,11 +266,11 @@ virNWFilterIncludeDefToRuleInst(virNWFilterIncludeDefPtr inc,
 static int
 virNWFilterDefToInst(const char *xml,
                      GHashTable *vars,
-                     virNWFilterInstPtr inst)
+                     virNWFilterInst *inst)
 {
     size_t i;
     int ret = -1;
-    virNWFilterDefPtr def = virNWFilterDefParseFile(xml);
+    virNWFilterDef *def = virNWFilterDefParseFile(xml);
 
     if (!def)
         return -1;
@@ -326,7 +325,7 @@ static int testSetOneParameter(GHashTable *vars,
                                const char *name,
                                const char *value)
 {
-    virNWFilterVarValuePtr val;
+    virNWFilterVarValue *val;
 
     if ((val = virHashLookup(vars, name)) == NULL) {
         val = virNWFilterVarValueCreateSimpleCopyValue(value);
@@ -371,10 +370,11 @@ static int testCompareXMLToArgvFiles(const char *xml,
     GHashTable *vars = virHashNew(virNWFilterVarValueHashFree);
     virNWFilterInst inst;
     int ret = -1;
+    g_autoptr(virCommandDryRunToken) dryRunToken = virCommandDryRunTokenNew();
 
     memset(&inst, 0, sizeof(inst));
 
-    virCommandSetDryRun(&buf, NULL, NULL);
+    virCommandSetDryRun(dryRunToken, &buf, true, true, NULL, NULL);
 
     if (!vars)
         goto cleanup;
@@ -391,12 +391,10 @@ static int testCompareXMLToArgvFiles(const char *xml,
         goto cleanup;
 
     actualargv = virBufferContentAndReset(&buf);
-    virTestClearCommandPath(actualargv);
-    virCommandSetDryRun(NULL, NULL, NULL);
 
     testRemoveCommonRules(actualargv);
 
-    if (virTestCompareToFile(actualargv, cmdline) < 0)
+    if (virTestCompareToFileFull(actualargv, cmdline, false) < 0)
         goto cleanup;
 
     ret = 0;
@@ -433,14 +431,6 @@ testCompareXMLToIPTablesHelper(const void *data)
     return result;
 }
 
-static bool
-hasNetfilterTools(void)
-{
-    return virFileIsExecutable(IPTABLES_PATH) &&
-        virFileIsExecutable(IP6TABLES_PATH) &&
-        virFileIsExecutable(EBTABLES_PATH);
-}
-
 
 static int
 mymain(void)
@@ -458,10 +448,6 @@ mymain(void)
     } while (0)
 
     if (virFirewallSetBackend(VIR_FIREWALL_BACKEND_DIRECT) < 0) {
-        if (!hasNetfilterTools()) {
-            fprintf(stderr, "iptables/ip6tables/ebtables tools not present");
-            return EXIT_AM_SKIP;
-        }
         return EXIT_FAILURE;
     }
 
@@ -508,7 +494,7 @@ mymain(void)
     return ret == 0 ? EXIT_SUCCESS : EXIT_FAILURE;
 }
 
-VIR_TEST_MAIN(mymain)
+VIR_TEST_MAIN_PRELOAD(mymain, VIR_TEST_MOCK("virfirewall"))
 
 #else /* ! defined (__linux__) */
 
