@@ -45,7 +45,9 @@ int
 main(int argc, char **argv)
 {
     virThread thread;
-    virQEMUCapsPtr caps;
+    virQEMUCaps *caps;
+    virArch host;
+    virArch guest;
     const char *mock = VIR_TEST_MOCK("qemucapsprobe");
 
     if (!virFileIsExecutable(mock)) {
@@ -80,6 +82,18 @@ main(int argc, char **argv)
                                                  -1, -1, NULL, 0, NULL)))
         return EXIT_FAILURE;
 
+    host = virArchFromHost();
+    guest = virQEMUCapsGetArch(caps);
+
+    if (host != guest) {
+        fprintf(stderr,
+                "WARNING: guest architecture '%s' does not match host '%s'.\n"
+                "WARNING: When generating capabilities for the libvirt test\n"
+                "WARNING: suite, it is strongly desired to generate capabilities\n"
+                "WARNING: on the native host to capture KVM related features.\n",
+                virArchToString(guest), virArchToString(host));
+    }
+
     virObjectUnref(caps);
 
     return EXIT_SUCCESS;
