@@ -158,7 +158,7 @@ cmdCheckpointCreate(vshControl *ctl,
  */
 static int
 virshParseCheckpointDiskspec(vshControl *ctl,
-                             virBufferPtr buf,
+                             virBuffer *buf,
                              const char *str)
 {
     int ret = -1;
@@ -540,10 +540,9 @@ struct virshCheckpointList {
     struct virshChk *chks;
     int nchks;
 };
-typedef struct virshCheckpointList *virshCheckpointListPtr;
 
 static void
-virshCheckpointListFree(virshCheckpointListPtr checkpointlist)
+virshCheckpointListFree(struct virshCheckpointList *checkpointlist)
 {
     size_t i;
 
@@ -581,7 +580,7 @@ virshChkSorter(const void *a,
  * list is limited to descendants of the given checkpoint.  If FLAGS is
  * given, the list is filtered.  If TREE is specified, then all but
  * FROM or the roots will also have parent information.  */
-static virshCheckpointListPtr
+static struct virshCheckpointList *
 virshCheckpointListCollect(vshControl *ctl,
                            virDomainPtr dom,
                            virDomainCheckpointPtr from,
@@ -591,8 +590,8 @@ virshCheckpointListCollect(vshControl *ctl,
     size_t i;
     int count = -1;
     virDomainCheckpointPtr *chks;
-    virshCheckpointListPtr checkpointlist = NULL;
-    virshCheckpointListPtr ret = NULL;
+    struct virshCheckpointList *checkpointlist = NULL;
+    struct virshCheckpointList *ret = NULL;
     unsigned int flags = orig_flags;
 
     checkpointlist = g_new0(struct virshCheckpointList, 1);
@@ -629,7 +628,8 @@ virshCheckpointListCollect(vshControl *ctl,
         }
     }
 
-    if (!(orig_flags & VIR_DOMAIN_CHECKPOINT_LIST_TOPOLOGICAL))
+    if (!(orig_flags & VIR_DOMAIN_CHECKPOINT_LIST_TOPOLOGICAL) &&
+        checkpointlist->chks)
         qsort(checkpointlist->chks, checkpointlist->nchks,
               sizeof(*checkpointlist->chks), virshChkSorter);
 
@@ -646,7 +646,7 @@ virshCheckpointListLookup(int id,
                           bool parent,
                           void *opaque)
 {
-    virshCheckpointListPtr checkpointlist = opaque;
+    struct virshCheckpointList *checkpointlist = opaque;
     if (parent)
         return checkpointlist->chks[id].parent;
     return virDomainCheckpointGetName(checkpointlist->chks[id].chk);
@@ -722,7 +722,6 @@ cmdCheckpointList(vshControl *ctl,
     virDomainCheckpointPtr checkpoint = NULL;
     long long creation_longlong;
     g_autoptr(GDateTime) then = NULL;
-    g_autofree gchar *thenstr = NULL;
     bool tree = vshCommandOptBool(cmd, "tree");
     bool name = vshCommandOptBool(cmd, "name");
     bool from = vshCommandOptBool(cmd, "from");
@@ -731,8 +730,8 @@ cmdCheckpointList(vshControl *ctl,
     const char *from_chk = NULL;
     char *parent_chk = NULL;
     virDomainCheckpointPtr start = NULL;
-    virshCheckpointListPtr checkpointlist = NULL;
-    vshTablePtr table = NULL;
+    struct virshCheckpointList *checkpointlist = NULL;
+    vshTable *table = NULL;
 
     VSH_EXCLUSIVE_OPTIONS_VAR(tree, name);
     VSH_EXCLUSIVE_OPTIONS_VAR(parent, roots);
@@ -805,6 +804,7 @@ cmdCheckpointList(vshControl *ctl,
     }
 
     for (i = 0; i < checkpointlist->nchks; i++) {
+        g_autofree gchar *thenstr = NULL;
         const char *chk_name;
 
         /* free up memory from previous iterations of the loop */
