@@ -35,6 +35,7 @@
 #include "virkeynametable_linux.h"
 #include "virkeynametable_osx.h"
 #include "virkeynametable_win32.h"
+#include "conf/storage_conf.h"
 
 char **
 virshDomainNameCompleter(vshControl *ctl,
@@ -940,3 +941,58 @@ virshDomainFSMountpointsCompleter(vshControl *ctl,
     virshDomainFree(dom);
     return ret;
 }
+
+
+char **
+virshDomainCoreDumpFormatCompleter(vshControl *ctl G_GNUC_UNUSED,
+                                   const vshCmd *cmd G_GNUC_UNUSED,
+                                   unsigned int flags)
+{
+    char **ret = NULL;
+    size_t i;
+
+    virCheckFlags(0, NULL);
+
+    ret = g_new0(char *, VIR_DOMAIN_CORE_DUMP_FORMAT_LAST + 1);
+
+    for (i = 0; i < VIR_DOMAIN_CORE_DUMP_FORMAT_LAST; i++)
+        ret[i] = g_strdup(virDomainCoreDumpFormatTypeToString(i));
+
+    return ret;
+}
+
+
+char **
+virshDomainMigrateCompMethodsCompleter(vshControl *ctl,
+                                       const vshCmd *cmd,
+                                       unsigned int flags)
+{
+    const char *methods[] = {"xbzrle", "mt",  NULL};
+    const char *method = NULL;
+
+    virCheckFlags(0, NULL);
+
+    if (vshCommandOptStringQuiet(ctl, cmd, "comp-methods", &method) < 0)
+        return NULL;
+
+    return virshCommaStringListComplete(method, methods);
+}
+
+
+char **
+virshDomainStorageFileFormatCompleter(vshControl *ctl G_GNUC_UNUSED,
+                                      const vshCmd *cmd G_GNUC_UNUSED,
+                                      unsigned int flags)
+{
+    char **ret = NULL;
+    size_t i;
+
+    virCheckFlags(0, NULL);
+
+    ret = g_new0(char *, VIR_STORAGE_FILE_LAST + 1);
+
+    for (i = 0; i < VIR_STORAGE_FILE_LAST; i++)
+        ret[i] = g_strdup(virStorageFileFormatTypeToString(i));
+
+    return ret;
+}
