@@ -26,6 +26,7 @@
 #include "virstring.h"
 #include "virxml.h"
 #include "virutil.h"
+#include "virsh-host.h"
 
 static char *
 virshPagesizeNodeToString(xmlNodePtr node)
@@ -167,3 +168,22 @@ virshNodeCpuCompleter(vshControl *ctl,
 
     return g_steal_pointer(&tmp);
 }
+
+
+char **
+virshNodeSuspendTargetCompleter(vshControl *ctl G_GNUC_UNUSED,
+                                const vshCmd *cmd G_GNUC_UNUSED,
+                                unsigned int flags)
+{
+    char **ret = NULL;
+    size_t i;
+
+    virCheckFlags(0, NULL);
+
+    ret = g_new0(char *, VIR_NODE_SUSPEND_TARGET_LAST + 1);
+
+    for (i = 0; i < VIR_NODE_SUSPEND_TARGET_LAST; i++)
+        ret[i] = g_strdup(virNodeSuspendTargetTypeToString(i));
+
+    return ret;
+}
