@@ -21,5 +21,8 @@
 #pragma once
 
 #include "vsh.h"
+#include "virenum.h"
 
 extern const vshCmdDef hostAndHypervisorCmds[];
+
+VIR_ENUM_DECL(virNodeSuspendTarget);
